@@ -18,10 +18,10 @@
  * @brief logic to load single page app (/spa)
  * @author Christian Grothoff
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include <gnunet/gnunet_util_lib.h>
-#include "taler_util.h"
-#include "taler_mhd_lib.h"
+#include "taler/taler_util.h"
+#include "taler/taler_mhd_lib.h"
 #include <gnunet/gnunet_mhd_compat.h>
 #include "taler-auditor-httpd_spa.h"
 
