@@ -21,16 +21,16 @@
  * This auditor verifies that 'reserves_in' actually matches
  * the incoming wire transfers from the bank.
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include <gnunet/gnunet_util_lib.h>
 #include <gnunet/gnunet_curl_lib.h>
-#include "taler_auditordb_plugin.h"
-#include "taler_exchangedb_lib.h"
-#include "taler_json_lib.h"
-#include "taler_bank_service.h"
-#include "taler_signatures.h"
+#include "taler/taler_auditordb_plugin.h"
+#include "taler/taler_exchangedb_lib.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_bank_service.h"
+#include "taler/taler_signatures.h"
 #include "report-lib.h"
-#include "taler_dbevents.h"
+#include "taler/taler_dbevents.h"
 
 
 /**
