@@ -143,6 +143,10 @@ function check_with_database()
 # test required commands exist
 echo "Testing for jq"
 jq -h > /dev/null || exit_skip "jq required"
+echo "Testing for taler-merchant-config"
+taler-merchant-config -h > /dev/null || exit_skip "taler-merchant-config required"
+echo "Testing for taler-merchant-httpd"
+taler-merchant-httpd -h > /dev/null || exit_skip "taler-merchant-httpd required"
 echo "Testing for faketime"
 faketime -h > /dev/null || exit_skip "faketime required"
 echo "Testing for libeufin-bank"
