@@ -16,8 +16,8 @@
 #ifndef SRC_PG_INSERT_BAD_SIG_LOSSES_H
 #define SRC_PG_INSERT_BAD_SIG_LOSSES_H
 
-#include "taler_util.h"
-#include "taler_auditordb_plugin.h"
+#include "taler/taler_util.h"
+#include "taler/taler_auditordb_plugin.h"
 
 
 /**
