@@ -18,8 +18,8 @@
 #ifndef SRC_PG_INSERT_DENOMINATION_PENDING_H
 #define SRC_PG_INSERT_DENOMINATION_PENDING_H
 
-#include "taler_util.h"
-#include "taler_auditordb_plugin.h"
+#include "taler/taler_util.h"
+#include "taler/taler_auditordb_plugin.h"
 
 
 /**
