@@ -32,6 +32,9 @@
  *
  * @param cls closure
  * @param deadline only return up to this deadline
+ * @param limit number of rows to return, negative to iterate backwards
+ * @param offset starting offset, exclusive
+ * @param return_suppressed true to also return suppressed events
  * @param cb function to call on each entry
  * @param cb_cls closure for @a cb
  * @return transaction status code
@@ -40,6 +43,9 @@ enum GNUNET_DB_QueryStatus
 TAH_PG_select_pending_deposits (
   void *cls,
   struct GNUNET_TIME_Absolute deadline,
+  int64_t limit,
+  uint64_t offset,
+  bool return_suppressed,
   TALER_AUDITORDB_WireMissingCallback cb,
   void *cb_cls);
 
