@@ -19,11 +19,11 @@
  * @brief Implementation of the /admin/add-kycauth requests of the bank's HTTP API
  * @author Christian Grothoff
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include "bank_api_common.h"
 #include <microhttpd.h> /* just for HTTP status codes */
-#include "taler_signatures.h"
-#include "taler_curl_lib.h"
+#include "taler/taler_signatures.h"
+#include "taler/taler_curl_lib.h"
 
 
 /**
