@@ -25,8 +25,8 @@
 #include <gnunet/gnunet_util_lib.h>
 #include <gnunet/gnunet_json_lib.h>
 #include <gnunet/gnunet_curl_lib.h>
-#include "taler_bank_service.h"
-#include "taler_json_lib.h"
+#include "taler/taler_bank_service.h"
+#include "taler/taler_json_lib.h"
 
 
 /**
