@@ -24,18 +24,18 @@
  */
 // FIXME: support use of more than one 'client' bank account
 // FIXME: add taler-exchange-transfer to simulate outgoing payments
-#include "platform.h"
+#include "taler/platform.h"
 #include <gnunet/gnunet_util_lib.h>
 #include <microhttpd.h>
 #include <sys/resource.h>
-#include "taler_util.h"
-#include "taler_signatures.h"
-#include "taler_json_lib.h"
-#include "taler_bank_service.h"
-#include "taler_exchangedb_lib.h"
-#include "taler_fakebank_lib.h"
-#include "taler_testing_lib.h"
-#include "taler_error_codes.h"
+#include "taler/taler_util.h"
+#include "taler/taler_signatures.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_bank_service.h"
+#include "taler/taler_exchangedb_lib.h"
+#include "taler/taler_fakebank_lib.h"
+#include "taler/taler_testing_lib.h"
+#include "taler/taler_error_codes.h"
 
 #define SHARD_SIZE "1024"
 
