@@ -21,8 +21,8 @@
  * @brief Helper routines for interactions with libcurl
  * @author Christian Grothoff
  */
-#include "platform.h"
-#include "taler_curl_lib.h"
+#include "taler/platform.h"
+#include "taler/taler_curl_lib.h"
 
 
 #if TALER_CURL_COMPRESS_BODIES
