@@ -19,16 +19,16 @@
  * @brief Process that aggregates outgoing transactions and prepares their execution
  * @author Christian Grothoff
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include <gnunet/gnunet_util_lib.h>
 #include <jansson.h>
 #include <pthread.h>
-#include "taler_exchangedb_lib.h"
-#include "taler_exchangedb_plugin.h"
-#include "taler_json_lib.h"
-#include "taler_kyclogic_lib.h"
-#include "taler_bank_service.h"
-#include "taler_dbevents.h"
+#include "taler/taler_exchangedb_lib.h"
+#include "taler/taler_exchangedb_plugin.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_kyclogic_lib.h"
+#include "taler/taler_bank_service.h"
+#include "taler/taler_dbevents.h"
 
 /**
  * How often do we retry after serialization failures?
