@@ -19,14 +19,14 @@
  *        and puts them into some regular account of the exchange.
  * @author Christian Grothoff
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include <gnunet/gnunet_util_lib.h>
 #include <jansson.h>
 #include <pthread.h>
-#include "taler_exchangedb_lib.h"
-#include "taler_exchangedb_plugin.h"
-#include "taler_json_lib.h"
-#include "taler_bank_service.h"
+#include "taler/taler_exchangedb_lib.h"
+#include "taler/taler_exchangedb_plugin.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_bank_service.h"
 
 
 /**
