@@ -211,6 +211,11 @@ char *TEH_obg_url;
  */
 static char *toplevel_redirect_url;
 
+/**
+ * Form data to inject into any Typst form generation.
+ */
+json_t *TEH_global_pdf_form_data;
+
 /**
  * Our currency.
  */
@@ -2442,6 +2447,32 @@ exchange_serve_process_config (const char *cfg_fn)
     GNUNET_free (attr_enc_key_str);
   }
 
+  {
+    char *pdf_data;
+
+    if (GNUNET_OK ==
+        GNUNET_CONFIGURATION_get_value_string (TEH_cfg,
+                                               "exchange",
+                                               "GLOBAL_PDF_FORM_DATA",
+                                               &pdf_data))
+    {
+      json_error_t err;
+
+      TEH_global_pdf_form_data = json_loads (pdf_data,
+                                             JSON_REJECT_DUPLICATES,
+                                             &err);
+      GNUNET_free (pdf_data);
+      if (NULL == TEH_global_pdf_form_data)
+      {
+        GNUNET_log_config_invalid (GNUNET_ERROR_TYPE_ERROR,
+                                   "exchange",
+                                   "GLOBAL_PDF_FORM_DATA",
+                                   err.text);
+        return GNUNET_SYSERR;
+      }
+    }
+  }
+
   for (unsigned int i = 0; i<MAX_DB_RETRIES; i++)
   {
     TEH_plugin = TALER_EXCHANGEDB_plugin_load (TEH_cfg,
@@ -2735,6 +2766,7 @@ do_shutdown (void *cls)
   TEH_kyc_proof_cleanup ();
   TEH_kyc_start_cleanup ();
   TEH_aml_decision_cleanup ();
+  TEH_handler_aml_attributes_get_cleanup ();
   TALER_KYCLOGIC_kyc_done ();
   TALER_MHD_daemons_destroy ();
   TEH_extensions_done ();
