@@ -169,6 +169,11 @@ extern float TEH_stefan_lin;
  */
 extern const struct TALER_CurrencySpecification *TEH_cspec;
 
+/**
+ * Form data to inject into any Typst form generation.
+ */
+extern json_t *TEH_global_pdf_form_data;
+
 /**
  * Our currency.
  */
