@@ -1,6 +1,6 @@
 /*
   This file is part of TALER
-  Copyright (C) 2024 Taler Systems SA
+  Copyright (C) 2024, 2025 Taler Systems SA
 
   TALER is free software; you can redistribute it and/or modify it under the
   terms of the GNU Affero General Public License as published by the Free Software
@@ -18,16 +18,16 @@
  * @brief Return summary information about AML decisions
  * @author Christian Grothoff
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include <gnunet/gnunet_util_lib.h>
 #include <jansson.h>
 #include <microhttpd.h>
 #include <pthread.h>
-#include "taler_json_lib.h"
-#include "taler_mhd_lib.h"
-#include "taler_signatures.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_mhd_lib.h"
+#include "taler/taler_signatures.h"
 #include "taler-exchange-httpd.h"
-#include "taler_exchangedb_plugin.h"
+#include "taler/taler_exchangedb_plugin.h"
 #include "taler-exchange-httpd_aml-decision.h"
 #include "taler-exchange-httpd_metrics.h"
 
@@ -50,6 +50,7 @@
  * @param to_investigate true if AML staff should look at the account
  * @param is_active true if this is the currently active decision about the account
  * @param is_wallet true if the @a h_payto is for a wallet
+ * @param payto the payto URI of the account affected by the decision
  * @param account_rules current active rules for the account
  */
 static void
@@ -64,6 +65,7 @@ record_cb (
   bool to_investigate,
   bool is_active,
   bool is_wallet,
+  struct TALER_FullPayto payto,
   const json_t *account_rules)
 {
   json_t *records = cls;
@@ -75,6 +77,8 @@ record_cb (
       GNUNET_JSON_PACK (
         GNUNET_JSON_pack_data_auto ("h_payto",
                                     h_payto),
+        TALER_JSON_pack_full_payto ("full_payto",
+                                    payto),
         GNUNET_JSON_pack_bool ("is_wallet",
                                is_wallet),
         GNUNET_JSON_pack_int64 ("rowid",
