@@ -18,12 +18,12 @@
  * @brief Handle GET /coins/$COIN_PUB/history requests
  * @author Christian Grothoff
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include <gnunet/gnunet_util_lib.h>
 #include <jansson.h>
-#include "taler_mhd_lib.h"
-#include "taler_json_lib.h"
-#include "taler_dbevents.h"
+#include "taler/taler_mhd_lib.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_dbevents.h"
 #include "taler-exchange-httpd_keys.h"
 #include "taler-exchange-httpd_coins_get.h"
 #include "taler-exchange-httpd_responses.h"
@@ -116,27 +116,46 @@ compile_transaction_history (
               GNUNET_JSON_PACK (
                 GNUNET_JSON_pack_string ("type",
                                          "DEPOSIT"),
+                GNUNET_JSON_pack_uint64 ("history_offset",
+                                         pos->coin_history_id),
                 TALER_JSON_pack_amount ("amount",
                                         &deposit->amount_with_fee),
                 TALER_JSON_pack_amount ("deposit_fee",
                                         &deposit->deposit_fee),
+                GNUNET_JSON_pack_data_auto ("merchant_pub",
+                                            &deposit->merchant_pub),
                 GNUNET_JSON_pack_timestamp ("timestamp",
                                             deposit->timestamp),
                 GNUNET_JSON_pack_allow_null (
                   GNUNET_JSON_pack_timestamp ("refund_deadline",
                                               deposit->refund_deadline)),
-                GNUNET_JSON_pack_data_auto ("merchant_pub",
-                                            &deposit->merchant_pub),
                 GNUNET_JSON_pack_data_auto ("h_contract_terms",
                                             &deposit->h_contract_terms),
                 GNUNET_JSON_pack_data_auto ("h_wire",
                                             &h_wire),
+                GNUNET_JSON_pack_data_auto ("h_denom_pub",
+                                            &deposit->h_denom_pub),
                 GNUNET_JSON_pack_allow_null (
-                  deposit->no_age_commitment ?
-                  GNUNET_JSON_pack_string (
-                    "h_age_commitment", NULL) :
-                  GNUNET_JSON_pack_data_auto ("h_age_commitment",
-                                              &deposit->h_age_commitment)),
+                  deposit->has_policy
+                  ? GNUNET_JSON_pack_data_auto ("h_policy",
+                                                &deposit->h_policy)
+                  : GNUNET_JSON_pack_string (
+                    "h_policy",
+                    NULL)),
+                GNUNET_JSON_pack_allow_null (
+                  deposit->no_wallet_data_hash
+                  ? GNUNET_JSON_pack_string (
+                    "wallet_data_hash",
+                    NULL)
+                  : GNUNET_JSON_pack_data_auto ("wallet_data_hash",
+                                                &deposit->wallet_data_hash)),
+                GNUNET_JSON_pack_allow_null (
+                  deposit->no_age_commitment
+                  ? GNUNET_JSON_pack_string (
+                    "h_age_commitment",
+                    NULL)
+                  : GNUNET_JSON_pack_data_auto ("h_age_commitment",
+                                                &deposit->h_age_commitment)),
                 GNUNET_JSON_pack_data_auto ("coin_sig",
                                             &deposit->csig))))
         {
@@ -150,7 +169,7 @@ compile_transaction_history (
       {
         const struct TALER_EXCHANGEDB_MeltListEntry *melt =
           pos->details.melt;
-        const struct TALER_AgeCommitmentHash *phac;
+        const struct TALER_AgeCommitmentHashP *phac;
         const struct TALER_BlindingMasterSeedP *pbs;
 
 #if ENABLE_SANITY_CHECKS
@@ -170,7 +189,6 @@ compile_transaction_history (
           return NULL;
         }
 #endif
-
         phac = (melt->no_age_commitment)
                 ? NULL
                 :  &melt->h_age_commitment;
@@ -183,12 +201,16 @@ compile_transaction_history (
               GNUNET_JSON_PACK (
                 GNUNET_JSON_pack_string ("type",
                                          "MELT"),
+                GNUNET_JSON_pack_uint64 ("history_offset",
+                                         pos->coin_history_id),
                 TALER_JSON_pack_amount ("amount",
                                         &melt->amount_with_fee),
                 TALER_JSON_pack_amount ("melt_fee",
                                         &melt->melt_fee),
                 GNUNET_JSON_pack_data_auto ("rc",
                                             &melt->rc),
+                GNUNET_JSON_pack_data_auto ("h_denom_pub",
+                                            &melt->h_denom_pub),
                 GNUNET_JSON_pack_data_auto ("refresh_seed",
                                             &melt->refresh_seed),
                 GNUNET_JSON_pack_allow_null (
@@ -243,6 +265,8 @@ compile_transaction_history (
               GNUNET_JSON_PACK (
                 GNUNET_JSON_pack_string ("type",
                                          "REFUND"),
+                GNUNET_JSON_pack_uint64 ("history_offset",
+                                         pos->coin_history_id),
                 TALER_JSON_pack_amount ("amount",
                                         &value),
                 TALER_JSON_pack_amount ("refund_fee",
@@ -294,6 +318,8 @@ compile_transaction_history (
               GNUNET_JSON_PACK (
                 GNUNET_JSON_pack_string ("type",
                                          "OLD-COIN-RECOUP"),
+                GNUNET_JSON_pack_uint64 ("history_offset",
+                                         pos->coin_history_id),
                 TALER_JSON_pack_amount ("amount",
                                         &pr->value),
                 GNUNET_JSON_pack_data_auto ("exchange_sig",
@@ -338,6 +364,8 @@ compile_transaction_history (
               GNUNET_JSON_PACK (
                 GNUNET_JSON_pack_string ("type",
                                          "RECOUP"),
+                GNUNET_JSON_pack_uint64 ("history_offset",
+                                         pos->coin_history_id),
                 TALER_JSON_pack_amount ("amount",
                                         &recoup->value),
                 GNUNET_JSON_pack_data_auto ("exchange_sig",
@@ -348,8 +376,12 @@ compile_transaction_history (
                                             &recoup->reserve_pub),
                 GNUNET_JSON_pack_data_auto ("coin_sig",
                                             &recoup->coin_sig),
+                GNUNET_JSON_pack_data_auto ("h_denom_pub",
+                                            &recoup->h_denom_pub),
                 GNUNET_JSON_pack_data_auto ("coin_blind",
                                             &recoup->coin_blind),
+                // FIXME-9828: spec says we should have h_commitment?
+                // FIXME-9828: spec says we should have coin_index?
                 GNUNET_JSON_pack_data_auto ("reserve_pub",
                                             &recoup->reserve_pub),
                 GNUNET_JSON_pack_timestamp ("timestamp",
@@ -393,6 +425,8 @@ compile_transaction_history (
               GNUNET_JSON_PACK (
                 GNUNET_JSON_pack_string ("type",
                                          "RECOUP-REFRESH"),
+                GNUNET_JSON_pack_uint64 ("history_offset",
+                                         pos->coin_history_id),
                 TALER_JSON_pack_amount ("amount",
                                         &pr->value),
                 GNUNET_JSON_pack_data_auto ("exchange_sig",
@@ -403,8 +437,13 @@ compile_transaction_history (
                                             &pr->old_coin_pub),
                 GNUNET_JSON_pack_data_auto ("coin_sig",
                                             &pr->coin_sig),
+                // FIXME-#9828: spec says to return h_denom_pub
                 GNUNET_JSON_pack_data_auto ("coin_blind",
                                             &pr->coin_blind),
+                // FIXME-#9828: spec says to return h_commitment
+                // FIXME-#9828: spec says to return coin_index
+                // FIXME-#9828: spec says to return new_coin_blinding_secret
+                // FIXME-#9828: spec says to return new_coin_ev
                 GNUNET_JSON_pack_timestamp ("timestamp",
                                             pr->timestamp))))
         {
@@ -419,17 +458,18 @@ compile_transaction_history (
       {
         struct TALER_EXCHANGEDB_PurseDepositListEntry *pd
           = pos->details.purse_deposit;
-        const struct TALER_AgeCommitmentHash *phac = NULL;
+        const struct TALER_AgeCommitmentHashP *phac = NULL;
 
         if (! pd->no_age_commitment)
           phac = &pd->h_age_commitment;
-
         if (0 !=
             json_array_append_new (
               history,
               GNUNET_JSON_PACK (
                 GNUNET_JSON_pack_string ("type",
                                          "PURSE-DEPOSIT"),
+                GNUNET_JSON_pack_uint64 ("history_offset",
+                                         pos->coin_history_id),
                 TALER_JSON_pack_amount ("amount",
                                         &pd->amount),
                 GNUNET_JSON_pack_string ("exchange_base_url",
@@ -439,12 +479,16 @@ compile_transaction_history (
                 GNUNET_JSON_pack_allow_null (
                   GNUNET_JSON_pack_data_auto ("h_age_commitment",
                                               phac)),
+                TALER_JSON_pack_amount ("deposit_fee",
+                                        &pd->deposit_fee),
                 GNUNET_JSON_pack_data_auto ("purse_pub",
                                             &pd->purse_pub),
                 GNUNET_JSON_pack_bool ("refunded",
                                        pd->refunded),
                 GNUNET_JSON_pack_data_auto ("coin_sig",
-                                            &pd->coin_sig))))
+                                            &pd->coin_sig),
+                GNUNET_JSON_pack_data_auto ("h_denom_pub",
+                                            &pd->h_denom_pub))))
         {
           GNUNET_break (0);
           json_decref (history);
@@ -491,6 +535,8 @@ compile_transaction_history (
               GNUNET_JSON_PACK (
                 GNUNET_JSON_pack_string ("type",
                                          "PURSE-REFUND"),
+                GNUNET_JSON_pack_uint64 ("history_offset",
+                                         pos->coin_history_id),
                 TALER_JSON_pack_amount ("amount",
                                         &value),
                 TALER_JSON_pack_amount ("refund_fee",
@@ -520,6 +566,8 @@ compile_transaction_history (
               GNUNET_JSON_PACK (
                 GNUNET_JSON_pack_string ("type",
                                          "RESERVE-OPEN-DEPOSIT"),
+                GNUNET_JSON_pack_uint64 ("history_offset",
+                                         pos->coin_history_id),
                 TALER_JSON_pack_amount ("coin_contribution",
                                         &role->coin_contribution),
                 GNUNET_JSON_pack_data_auto ("reserve_sig",
