@@ -213,7 +213,7 @@ TEH_handler_kyc_check (
   bool aml_review;
   bool kyc_required;
   bool access_ok = false;
-  bool is_wallet;
+  enum GNUNET_GenericReturnValue is_wallet;
   uint64_t rule_gen = 0;
 
   if (NULL == kyp)
@@ -341,10 +341,7 @@ TEH_handler_kyc_check (
         TALER_EC_GENERIC_DB_STORE_FAILED,
         "lookup_kyc_requirement_by_row");
     }
-    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
-                "Found rule %llu (client wants > %llu)\n",
-                (unsigned long long) rule_gen,
-                (unsigned long long) kyp->min_rule);
+
     do_suspend = false;
     if (GNUNET_DB_STATUS_SUCCESS_NO_RESULTS == qs)
     {
@@ -361,6 +358,10 @@ TEH_handler_kyc_check (
     }
     else
     {
+      GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                  "Found rule %llu (client wants > %llu)\n",
+                  (unsigned long long) rule_gen,
+                  (unsigned long long) kyp->min_rule);
       access_ok =
         ( (! GNUNET_is_zero (&kyp->account_pub) &&
            (GNUNET_OK ==
@@ -446,10 +447,13 @@ TEH_handler_kyc_check (
       GNUNET_JSON_pack_data_auto ("expected_account_pub",
                                   &kyp->account_pub));
   }
-
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
               "KYC rules apply to %s:\n",
-              is_wallet ? "wallet" : "account");
+              (GNUNET_SYSERR == is_wallet)
+              ? "unknown account type"
+              : ( (GNUNET_YES == is_wallet)
+                  ? "wallet"
+                  : "account"));
   if (NULL != jrules)
     json_dumpf (jrules,
                 stderr,
