@@ -25,6 +25,13 @@
 #include "taler-exchange-httpd.h"
 
 
+/**
+ * Resume suspended connections, we are shutting down.
+ */
+void
+TEH_kyc_wallet_cleanup (void);
+
+
 /**
  * Handle a "/kyc-wallet" request.  Parses the "reserve_pub" EdDSA key of the
  * reserve and the signature "reserve_sig" which affirms the operation. If OK,
