@@ -20,16 +20,16 @@
  * @author Özgür Kesim
  */
 
-#include "platform.h"
+#include "taler/platform.h"
 #include <gnunet/gnunet_util_lib.h>
 #include <jansson.h>
 #include "taler-exchange-httpd.h"
-#include "taler_json_lib.h"
-#include "taler_mhd_lib.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_mhd_lib.h"
 #include "taler-exchange-httpd_melt_v27.h"
 #include "taler-exchange-httpd_responses.h"
 #include "taler-exchange-httpd_keys.h"
-#include "taler_util.h"
+#include "taler/taler_util.h"
 
 /**
  * The different type of errors that might occur, sorted by name.
