@@ -18,14 +18,14 @@
  * @brief Handle /metrics requests
  * @author Christian Grothoff
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include <gnunet/gnunet_json_lib.h>
-#include "taler_dbevents.h"
+#include "taler/taler_dbevents.h"
 #include "taler-exchange-httpd_responses.h"
 #include "taler-exchange-httpd_keys.h"
 #include "taler-exchange-httpd_metrics.h"
-#include "taler_json_lib.h"
-#include "taler_mhd_lib.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_mhd_lib.h"
 #include <jansson.h>
 
 
@@ -128,6 +128,8 @@ TEH_handler_metrics (struct TEH_RequestContext *rc,
                    TEH_METRICS_num_requests[TEH_MT_REQUEST_IDEMPOTENT_DEPOSIT],
                    "melt",
                    TEH_METRICS_num_requests[TEH_MT_REQUEST_IDEMPOTENT_MELT],
+                   "kyc-upload",
+                   TEH_METRICS_num_requests[TEH_MT_REQUEST_KYC_UPLOAD],
 #endif
                    "rsa",
                    TEH_METRICS_num_signatures[TEH_MT_SIGNATURE_RSA],
