@@ -190,7 +190,8 @@ kyc_process_cb (void *cls,
   }
   json_object_foreach (attrs, name, val)
   {
-    bool requested = false;
+    bool requested = strcmp (name,
+                             "FORM_ID"); /* we always return the FORM_ID */
     size_t idx;
     json_t *str;
 
