@@ -20,11 +20,11 @@
  * @author Benedikt Mueller
  * @author Christian Grothoff
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include <gnunet/gnunet_util_lib.h>
 #include <jansson.h>
-#include "taler_json_lib.h"
-#include "taler_dbevents.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_dbevents.h"
 #include "taler-exchange-httpd_keys.h"
 #include "taler-exchange-httpd_reserves_history.h"
 #include "taler-exchange-httpd_responses.h"
