@@ -24,7 +24,7 @@
 #define TALER_EXCHANGE_HTTPD_RESERVES_HISTORY_H
 
 #include <microhttpd.h>
-#include "taler_mhd_lib.h"
+#include "taler/taler_mhd_lib.h"
 #include "taler-exchange-httpd.h"
 
 
