@@ -18,21 +18,23 @@
  * @brief Handle /reveal-melt requests
  * @author Özgür Kesim
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include <gnunet/gnunet_common.h>
 #include <gnunet/gnunet_util_lib.h>
 #include <jansson.h>
 #include <microhttpd.h>
 #include "taler-exchange-httpd_metrics.h"
-#include "taler_error_codes.h"
-#include "taler_exchangedb_plugin.h"
-#include "taler_mhd_lib.h"
+#include "taler/taler_error_codes.h"
+#include "taler/taler_exchangedb_plugin.h"
+#include "taler/taler_mhd_lib.h"
 #include "taler-exchange-httpd_mhd.h"
 #include "taler-exchange-httpd_reveal-melt.h"
 #include "taler-exchange-httpd_responses.h"
 #include "taler-exchange-httpd_keys.h"
 
 #define KAPPA_MINUS_1  (TALER_CNC_KAPPA - 1)
+
+
 /**
  * State for an /reveal-melt operation.
  */
@@ -137,7 +139,7 @@ find_original_refresh (
  * @param connection The MHD connection to handle
  * @param actx The context of the operation, only partially built at this time
  * @param[out] mhd_ret The result if a reply is queued for MHD
- * @return GNUNET_OK on success, otherwise a reply is queued for MHD
+ * @return #GNUNET_OK on success, otherwise a reply is queued for MHD and @a mhd_ret is set
  */
 static enum GNUNET_GenericReturnValue
 compare_age_commitment (
@@ -155,7 +157,7 @@ compare_age_commitment (
   }
   if (! actx->no_age_commitment)
   {
-    struct TALER_AgeCommitmentHash ach;
+    struct TALER_AgeCommitmentHashP ach;
 
     actx->age_commitment.mask = TEH_age_restriction_config.mask;
     TALER_age_commitment_hash (
@@ -188,7 +190,7 @@ compare_age_commitment (
  * @param old_age_commitment The age commitment of the old coin, might be NULL
  * @param[out] detail planchet detail to write  to write
  * @param[out] result On error, a HTTP-response will be queued and result set accordingly
- * @return GNUNET_OK on success, GNUNET_SYSERR otherwise, with an error message
+ * @return #GNUNET_OK on success, #GNUNET_SYSERR otherwise, with an error message
  * written to the client and @e result set.
  */
 static enum GNUNET_GenericReturnValue
@@ -203,7 +205,7 @@ calculate_blinded_detail (
   MHD_RESULT *result)
 {
   enum GNUNET_GenericReturnValue ret;
-  struct TALER_AgeCommitmentHash ach;
+  struct TALER_AgeCommitmentHashP ach;
   bool no_age_commitment = (NULL == old_age_commitment);
 
   /* calculate age commitment hash */
@@ -256,8 +258,8 @@ calculate_blinded_detail (
                                   nonce,
                                   &coin_priv,
                                   no_age_commitment
-                                     ? NULL
-                                     : &ach,
+                                  ? NULL
+                                  : &ach,
                                   &c_hash,
                                   detail);
     if (GNUNET_OK != ret)
@@ -296,7 +298,7 @@ calculate_blinded_detail (
  * @param old_age_commitment The age commitment of the original coin
  * @param signatures The secrets of the disclosed coins, KAPPA_MINUS_1*num_coins many
  * @param[out] result On error, a HTTP-response will be queued and result set accordingly
- * @return GNUNET_OK on success, GNUNET_SYSERR otherwise
+ * @return #GNUNET_OK on success, #GNUNET_SYSERR otherwise
  */
 static enum GNUNET_GenericReturnValue
 verify_commitment (
