@@ -1,6 +1,6 @@
 /*
   This file is part of TALER
-  Copyright (C) 2024 Taler Systems SA
+  Copyright (C) 2025 Taler Systems SA
 
   TALER is free software; you can redistribute it and/or modify it under the
   terms of the GNU Affero General Public License as published by the Free Software
@@ -15,10 +15,8 @@
 */
 /**
  * @file taler-exchange-httpd_withdraw.h
- * @brief Handle /reserve/$RESERVE_PUB/{age,batch}-withdraw requests
- * @author Florian Dold
- * @author Benedikt Mueller
- * @author Christian Grothoff
+ * @brief Handle /withdraw requests
+ * @note This endpoint was introduced in v26 of the protocol.
  * @author Özgür Kesim
  */
 #ifndef TALER_EXCHANGE_HTTPD_WITHDRAW_H
@@ -33,45 +31,31 @@
 void
 TEH_withdraw_cleanup (void);
 
-
 /**
- * Handle a "/reserves/$RESERVE_PUB/age-withdraw" request.
+ * @brief Handle a "/withdraw" request.
+ * @note This endpoint was introduced in v24 of the protocol.
  *
- * Parses the batch of commitments to withdraw age restricted coins, and checks
- * that the signature "reserve_sig" makes this a valid withdrawal request from
- * the specified reserve.  If the request is valid, the response contains a
- * noreveal_index which the client has to use for the subsequent call to
- * /age-withdraw/$ACH/reveal.
+ * Parses the batch of requested "denom_pub" which specifies
+ * the key/value of the respective coin to be withdrawn,
+ * and checks the signature "reserve_sig" for given "reserve_pub"
+ * makes this a valid withdrawal request from the specific reserve.
+ * If the "max_age" value is set in the request,
+ * it is considered a commitment to withdraw age restricted coins.
+ * If the request is valid, the response contains a  noreveal_index
+ * which the client has to use for the subsequent call to /reveal-withdraw.
+ * If "max_age" value is not set, and the request is valid, the envelopes
+ * with the blinded coins "blinded_coin_evs" is processed
+ * and the client receives the blinded signatures as response.
  *
  * @param rc request context
  * @param root uploaded JSON data
- * @param reserve_pub public key of the reserve
+ * @param args array of additional options, not used.
  * @return MHD result code
   */
 MHD_RESULT
-TEH_handler_age_withdraw (
+TEH_handler_withdraw (
   struct TEH_RequestContext *rc,
-  const struct TALER_ReservePublicKeyP *reserve_pub,
-  const json_t *root);
-
-
-/**
- * Handle a "/reserves/$RESERVE_PUB/batch-withdraw" request.  Parses the batch of
- * requested "denom_pub" which specifies the key/value of the coin to be
- * withdrawn, and checks that the signature "reserve_sig" makes this a valid
- * withdrawal request from the specified reserve.  If so, the envelope with
- * the blinded coin "coin_ev" is passed down to execute the withdrawal
- * operation.
- *
- * @param rc request context
- * @param root uploaded JSON data
- * @param reserve_pub public key of the reserve
- * @return MHD result code
-  */
-MHD_RESULT
-TEH_handler_batch_withdraw (
-  struct TEH_RequestContext *rc,
-  const struct TALER_ReservePublicKeyP *reserve_pub,
-  const json_t *root);
+  const json_t *root,
+  const char *const args[0]);
 
 #endif
