@@ -18,14 +18,14 @@
  * @brief Process that actually finalizes outgoing transfers with the wire gateway / bank
  * @author Christian Grothoff
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include <gnunet/gnunet_util_lib.h>
 #include <jansson.h>
 #include <pthread.h>
-#include "taler_exchangedb_lib.h"
-#include "taler_exchangedb_plugin.h"
-#include "taler_json_lib.h"
-#include "taler_bank_service.h"
+#include "taler/taler_exchangedb_lib.h"
+#include "taler/taler_exchangedb_plugin.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_bank_service.h"
 
 /**
  * What is the default batch size we use for credit history
