@@ -22,6 +22,8 @@ CREATE TABLE wire_accounts
   ,conversion_url TEXT DEFAULT (NULL)
   ,debit_restrictions TEXT DEFAULT (NULL)
   ,credit_restrictions TEXT DEFAULT (NULL)
+  ,priority INT8 NOT NULL DEFAULT (0)
+  ,bank_label TEXT DEFAULT (NULL)
   );
 COMMENT ON TABLE wire_accounts
   IS 'Table with current and historic bank accounts of the exchange. Entries never expire as we need to remember the last_change column indefinitely.';
@@ -39,6 +41,10 @@ COMMENT ON COLUMN wire_accounts.debit_restrictions
   IS 'JSON array describing restrictions imposed when debiting this account. Empty for no restrictions, NULL if account was migrated from previous database revision or account is disabled.';
 COMMENT ON COLUMN wire_accounts.credit_restrictions
   IS 'JSON array describing restrictions imposed when crediting this account. Empty for no restrictions, NULL if account was migrated from previous database revision or account is disabled.';
+COMMENT ON COLUMN wire_accounts.priority
+  IS 'priority determines the order in which wallets should display wire accounts';
+COMMENT ON COLUMN wire_accounts.bank_label
+  IS 'label to show in the selector for this bank account in the wallet UI';
 
 
 -- "wire_accounts" has no sequence because it is a 'mutable' table
