@@ -1,26 +1,22 @@
 BEGIN;
 SELECT _v.register_patch('exchange-0004', NULL, NULL);
 SET search_path TO exchange;
-CREATE FUNCTION constrain_table_refunds4 (
-  IN partition_suffix TEXT DEFAULT NULL
+CREATE OR REPLACE FUNCTION constrain_table_kyc_attributes4(
+  IN partition_suffix TEXT
 )
 RETURNS void
 LANGUAGE plpgsql
 AS $$
 DECLARE
-  table_name TEXT DEFAULT 'refunds';
+  table_name TEXT DEFAULT 'kyc_attributes';
 BEGIN
   table_name = concat_ws('_', table_name, partition_suffix);
   EXECUTE FORMAT (
     'ALTER TABLE ' || table_name ||
-    ' DROP CONSTRAINT ' || table_name || '_pkey'
+      ' ADD CONSTRAINT ' || table_name || '_legitimization_serial '
+        'UNIQUE (h_payto,legitimization_serial)'
   );
-  EXECUTE FORMAT (
-    'ALTER TABLE ' || table_name ||
-    ' ADD PRIMARY KEY (batch_deposit_serial_id, coin_pub, rtransaction_id) '
-  );
-END
-$$;
+END $$;
 INSERT INTO exchange_tables
     (name
     ,version
@@ -28,7 +24,7 @@ INSERT INTO exchange_tables
     ,partitioned
     ,by_range)
   VALUES
-    ('refunds4'
+    ('kyc_attributes4'
     ,'exchange-0004'
     ,'constrain'
     ,TRUE
