@@ -56,9 +56,9 @@ ELSE
   -- No constraint on merchant_pub, just create
   -- the wire_target.
   my_is_wallet
-      = (LOWER (SUBSTRING (in_payto_uri, 22)) =
+      = (LOWER (SUBSTRING (in_payto_uri, 0, 23)) =
          'payto://taler-reserve/') OR
-        (LOWER (SUBSTRING (in_payto_uri, 27)) =
+        (LOWER (SUBSTRING (in_payto_uri, 0, 28)) =
          'payto://taler-reserve-http/');
   INSERT INTO kyc_targets
     (h_normalized_payto
