@@ -18,11 +18,11 @@
  * @brief helper function to handle AML programs
  * @author Christian Grothoff
  */
-#include "taler_exchangedb_plugin.h"
-#include "taler_exchangedb_lib.h"
-#include "taler_kyclogic_lib.h"
-#include "taler_json_lib.h"
-#include "taler_dbevents.h"
+#include "taler/taler_exchangedb_plugin.h"
+#include "taler/taler_exchangedb_lib.h"
+#include "taler/taler_kyclogic_lib.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_dbevents.h"
 #include <gnunet/gnunet_common.h>
 
 /**
@@ -84,6 +84,7 @@ TALER_EXCHANGEDB_persist_aml_program_result (
         err,
         TALER_EC_EXCHANGE_KYC_AML_PROGRAM_MALFORMED_RESULT);
       *ret_pprs = TALER_EXCHANGEDB_PPRS_BAD_OUTCOME;
+      TALER_KYCLOGIC_rules_free (lrs);
       GNUNET_free (err);
       GNUNET_break (qs > 0);
       return qs;
@@ -477,7 +478,18 @@ run_measure (struct TALER_EXCHANGEDB_RuleUpdater *ru,
 
     /* Free previous one, in case we are iterating... */
     GNUNET_free (ru->aml_program_name);
-    ru->aml_program_name = GNUNET_strdup (m->prog_name);
+    if (NULL != m->prog_name)
+    {
+      ru->aml_program_name = GNUNET_strdup (m->prog_name);
+    }
+    else
+    {
+      /* How do we get to run a measure if the check type
+         is INFO (which is the only case where prog_name
+         is allowed to be NULL?) */
+      GNUNET_break (0);
+      ru->aml_program_name = NULL;
+    }
     qs = ru->plugin->set_aml_lock (
       ru->plugin->cls,
       &ru->account,
@@ -516,7 +528,7 @@ run_measure (struct TALER_EXCHANGEDB_RuleUpdater *ru,
       return;
     }
     GNUNET_log (GNUNET_ERROR_TYPE_INFO,
-                "Check is of type 'skip', running AML program %s.\n",
+                "Check is of type 'SKIP', running AML program %s.\n",
                 m->prog_name);
     GNUNET_assert (NULL == ru->t);
     ru->amlh = TALER_KYCLOGIC_run_aml_program3 (
