@@ -21,9 +21,9 @@
 #ifndef PG_COUNT_KNOWN_COINS_H
 #define PG_COUNT_KNOWN_COINS_H
 
-#include "taler_util.h"
-#include "taler_json_lib.h"
-#include "taler_exchangedb_plugin.h"
+#include "taler/taler_util.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_exchangedb_plugin.h"
 /**
  * Count the number of known coins by denomination.
  *
