@@ -21,9 +21,9 @@
 #ifndef PG_CREATE_AGGREGATION_TRANSIENT_H
 #define PG_CREATE_AGGREGATION_TRANSIENT_H
 
-#include "taler_util.h"
-#include "taler_json_lib.h"
-#include "taler_exchangedb_plugin.h"
+#include "taler/taler_util.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_exchangedb_plugin.h"
 /**
  * Create a new entry in the transient aggregation table.
  *
