@@ -21,9 +21,9 @@
 #ifndef PG_ENSURE_COIN_KNOWN_H
 #define PG_ENSURE_COIN_KNOWN_H
 
-#include "taler_util.h"
-#include "taler_json_lib.h"
-#include "taler_exchangedb_plugin.h"
+#include "taler/taler_util.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_exchangedb_plugin.h"
 /**
  * Make sure the given @a coin is known to the database.
  *
@@ -40,6 +40,6 @@ TEH_PG_ensure_coin_known (void *cls,
                           const struct TALER_CoinPublicInfo *coin,
                           uint64_t *known_coin_id,
                           struct TALER_DenominationHashP *denom_hash,
-                          struct TALER_AgeCommitmentHash *h_age_commitment);
+                          struct TALER_AgeCommitmentHashP *h_age_commitment);
 
 #endif
