@@ -18,11 +18,11 @@
  * @brief Low-level (statement-level) Postgres database access for the exchange
  * @author Christian Grothoff
  */
-#include "platform.h"
-#include "taler_error_codes.h"
-#include "taler_dbevents.h"
-#include "taler_exchangedb_plugin.h"
-#include "taler_pq_lib.h"
+#include "taler/platform.h"
+#include "taler/taler_error_codes.h"
+#include "taler/taler_dbevents.h"
+#include "taler/taler_exchangedb_plugin.h"
+#include "taler/taler_pq_lib.h"
 #include "pg_get_coin_transactions.h"
 #include "pg_helper.h"
 #include "pg_start_read_committed.h"
@@ -57,6 +57,11 @@ struct CoinHistoryContext
    */
   struct PostgresClosure *pg;
 
+  /**
+   * Our current offset in the coin history.
+   */
+  uint64_t chid;
+
   /**
    * Set to 'true' if the transaction failed.
    */
@@ -144,6 +149,7 @@ add_coin_deposit (void *cls,
     tl->type = TALER_EXCHANGEDB_TT_DEPOSIT;
     tl->details.deposit = deposit;
     tl->serial_id = serial_id;
+    tl->coin_history_id = chc->chid;
     chc->head = tl;
   }
 }
@@ -197,6 +203,8 @@ add_coin_purse_deposit (void *cls,
           GNUNET_PQ_result_spec_bool ("refunded",
                                       &deposit->refunded),
           &not_finished),
+        GNUNET_PQ_result_spec_auto_from_type ("denom_pub_hash",
+                                              &deposit->h_denom_pub),
         GNUNET_PQ_result_spec_end
       };
 
@@ -212,13 +220,17 @@ add_coin_purse_deposit (void *cls,
       }
       if (not_finished)
         deposit->refunded = false;
-      deposit->no_age_commitment = GNUNET_is_zero (&deposit->h_age_commitment);
+      /* double-check for all-zeros age commitment */
+      if (! deposit->no_age_commitment)
+        deposit->no_age_commitment
+          = GNUNET_is_zero (&deposit->h_age_commitment);
     }
     tl = GNUNET_new (struct TALER_EXCHANGEDB_TransactionList);
     tl->next = chc->head;
     tl->type = TALER_EXCHANGEDB_TT_PURSE_DEPOSIT;
     tl->details.purse_deposit = deposit;
     tl->serial_id = serial_id;
+    tl->coin_history_id = chc->chid;
     chc->head = tl;
   }
 }
@@ -291,6 +303,7 @@ add_coin_melt (void *cls,
     tl->type = TALER_EXCHANGEDB_TT_MELT;
     tl->details.melt = melt;
     tl->serial_id = serial_id;
+    tl->coin_history_id = chc->chid;
     chc->head = tl;
   }
 }
@@ -354,6 +367,7 @@ add_coin_refund (void *cls,
     tl->type = TALER_EXCHANGEDB_TT_REFUND;
     tl->details.refund = refund;
     tl->serial_id = serial_id;
+    tl->coin_history_id = chc->chid;
     chc->head = tl;
   }
 }
@@ -411,6 +425,7 @@ add_coin_purse_decision (void *cls,
     tl->type = TALER_EXCHANGEDB_TT_PURSE_REFUND;
     tl->details.purse_refund = prefund;
     tl->serial_id = serial_id;
+    tl->coin_history_id = chc->chid;
     chc->head = tl;
   }
 }
@@ -477,6 +492,7 @@ add_old_coin_recoup (void *cls,
     tl->type = TALER_EXCHANGEDB_TT_OLD_COIN_RECOUP;
     tl->details.old_coin_recoup = recoup;
     tl->serial_id = serial_id;
+    tl->coin_history_id = chc->chid;
     chc->head = tl;
   }
 }
@@ -540,6 +556,7 @@ add_coin_recoup (void *cls,
     tl->type = TALER_EXCHANGEDB_TT_RECOUP;
     tl->details.recoup = recoup;
     tl->serial_id = serial_id;
+    tl->coin_history_id = chc->chid;
     chc->head = tl;
   }
 }
@@ -606,6 +623,7 @@ add_coin_recoup_refresh (void *cls,
     tl->type = TALER_EXCHANGEDB_TT_RECOUP_REFRESH;
     tl->details.recoup_refresh = recoup;
     tl->serial_id = serial_id;
+    tl->coin_history_id = chc->chid;
     chc->head = tl;
   }
 }
@@ -663,6 +681,7 @@ add_coin_reserve_open (void *cls,
     tl->type = TALER_EXCHANGEDB_TT_RESERVE_OPEN;
     tl->details.reserve_open = role;
     tl->serial_id = serial_id;
+    tl->coin_history_id = chc->chid;
     chc->head = tl;
   }
 }
@@ -751,6 +770,8 @@ handle_history_entry (void *cls,
                                   &table_name),
     GNUNET_PQ_result_spec_uint64 ("serial_id",
                                   &serial_id),
+    GNUNET_PQ_result_spec_uint64 ("coin_history_serial_id",
+                                  &chc->chid),
     GNUNET_PQ_result_spec_end
   };
   struct GNUNET_PQ_QueryParam params[] = {
@@ -862,6 +883,7 @@ TEH_PG_get_coin_transactions (
            "SELECT"
            " table_name"
            ",serial_id"
+           ",coin_history_serial_id"
            " FROM coin_history"
            " WHERE coin_pub=$1"
            "   AND coin_history_serial_id > $2"
@@ -920,6 +942,7 @@ TEH_PG_get_coin_transactions (
            " partner_base_url"
            ",pd.amount_with_fee"
            ",denoms.fee_deposit"
+           ",denoms.denom_pub_hash"
            ",pd.purse_pub"
            ",kc.age_commitment_hash"
            ",pd.coin_sig"
