@@ -21,9 +21,9 @@
 #ifndef PG_GET_POLICY_DETAILS_H
 #define PG_GET_POLICY_DETAILS_H
 
-#include "taler_util.h"
-#include "taler_json_lib.h"
-#include "taler_exchangedb_plugin.h"
+#include "taler/taler_util.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_exchangedb_plugin.h"
 /* Get the details of a policy, referenced by its hash code
  *
  * @param cls the `struct PostgresClosure` with the plugin-specific state
