@@ -18,10 +18,10 @@
  * @brief Obtain (parts of) the history of a reserve.
  * @author Christian Grothoff
  */
-#include "platform.h"
-#include "taler_error_codes.h"
-#include "taler_dbevents.h"
-#include "taler_pq_lib.h"
+#include "taler/platform.h"
+#include "taler/taler_error_codes.h"
+#include "taler/taler_dbevents.h"
+#include "taler/taler_pq_lib.h"
 #include "pg_get_reserve_history.h"
 #include "pg_start_read_committed.h"
 #include "pg_commit.h"
@@ -815,24 +815,6 @@ TEH_PG_get_reserve_history (
            " FROM withdraw "
            " WHERE withdraw_id=$2"
            " AND reserve_pub=$1;");
-/* FIXME: remove "get_reserves_out" etc. once reserves_out is phased out */
-  PREPARE (pg,
-           "get_reserves_out",
-           "SELECT"
-           " ro.h_blind_ev"
-           ",denom.denom_pub_hash"
-           ",ro.denom_sig"
-           ",ro.reserve_sig"
-           ",ro.execution_date"
-           ",ro.amount_with_fee"
-           ",denom.fee_withdraw"
-           " FROM reserves_out ro"
-           " JOIN denominations denom"
-           "   USING (denominations_serial)"
-           " JOIN reserves res"
-           "   USING (reserve_uuid)"
-           " WHERE ro.reserve_out_serial_id=$2"
-           "   AND res.reserve_pub=$1;");
   PREPARE (pg,
            "recoup_by_reserve",
            "SELECT"
