@@ -21,9 +21,9 @@
 #ifndef PG_INSERT_AUDITOR_H
 #define PG_INSERT_AUDITOR_H
 
-#include "taler_util.h"
-#include "taler_json_lib.h"
-#include "taler_exchangedb_plugin.h"
+#include "taler/taler_util.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_exchangedb_plugin.h"
 
 /**
  * Insert information about an auditor that will audit this exchange.
@@ -42,4 +42,5 @@ TEH_PG_insert_auditor (void *cls,
                        const char *auditor_url,
                        const char *auditor_name,
                        struct GNUNET_TIME_Timestamp start_date);
+
 #endif
