@@ -275,7 +275,7 @@ irbt_cb_table_legitimization_measures (
            ",jmeasures"
            ",display_priority"
            ") VALUES "
-           "($1, $2, $3, $4, $5);");
+           "($1, $2, $3, $4::TEXT::JSONB, $5);");
   return GNUNET_PQ_eval_prepared_non_select (pg->conn,
                                              "insert_into_table_legitimization_measures",
                                              params);
@@ -321,7 +321,7 @@ irbt_cb_table_legitimization_outcomes (
            ",to_investigate"
            ",jnew_rules"
            ") VALUES "
-           "($1, $2, $3, $4, $5, $6, $7);");
+           "($1, $2, $3, $4, $5::TEXT::JSONB, $6, $7::TEXT::JSONB);");
   return GNUNET_PQ_eval_prepared_non_select (pg->conn,
                                              "insert_into_table_legitimization_outcomes",
                                              params);
@@ -1441,7 +1441,7 @@ irbt_cb_table_policy_fulfillments (struct PostgresClosure *pg,
            ",h_fulfillment_proof"
            ",policy_hash_codes"
            ") VALUES "
-           "($1, $2, $3, $4, $5);");
+           "($1, $2, $3::TEXT::JSONB, $4, $5);");
   return GNUNET_PQ_eval_prepared_non_select (pg->conn,
                                              "insert_into_table_policy_fulfillments",
                                              params);
