@@ -51,7 +51,7 @@ TEH_PG_lookup_active_legitimization (
   PREPARE (pg,
            "lookup_active_legitimization",
            "SELECT "
-           " lm.jmeasures"
+           " lm.jmeasures::TEXT"
            ",lp.measure_index"
            " FROM legitimization_processes lp"
            " JOIN legitimization_measures lm"
