@@ -72,6 +72,7 @@ handle_aml_entry (void *cls,
 
   for (unsigned int i = 0; i < num_results; i++)
   {
+    uint64_t outcome_serial_id;
     struct GNUNET_TIME_Timestamp decision_time;
     char *justification;
     struct TALER_AmlOfficerPublicKeyP decider_pub;
@@ -80,6 +81,8 @@ handle_aml_entry (void *cls,
     bool to_investigate;
     bool is_active;
     struct GNUNET_PQ_ResultSpec rs[] = {
+      GNUNET_PQ_result_spec_uint64 ("outcome_serial_id",
+                                    &outcome_serial_id),
       GNUNET_PQ_result_spec_timestamp ("decision_time",
                                        &decision_time),
       GNUNET_PQ_result_spec_string ("justification",
@@ -109,6 +112,7 @@ handle_aml_entry (void *cls,
       return;
     }
     ahc->cb (ahc->cb_cls,
+             outcome_serial_id,
              decision_time,
              justification,
              &decider_pub,
@@ -125,6 +129,8 @@ enum GNUNET_DB_QueryStatus
 TEH_PG_lookup_aml_history (
   void *cls,
   const struct TALER_NormalizedPaytoHashP *h_payto,
+  uint64_t offset,
+  int64_t limit,
   TALER_EXCHANGEDB_AmlHistoryCallback cb,
   void *cb_cls)
 {
@@ -134,16 +140,20 @@ TEH_PG_lookup_aml_history (
     .cb = cb,
     .cb_cls = cb_cls
   };
+  uint64_t ulimit = (limit < 0) ? (-limit) : limit;
   struct GNUNET_PQ_QueryParam params[] = {
     GNUNET_PQ_query_param_auto_from_type (h_payto),
+    GNUNET_PQ_query_param_uint64 (&offset),
+    GNUNET_PQ_query_param_uint64 (&ulimit),
     GNUNET_PQ_query_param_end
   };
   enum GNUNET_DB_QueryStatus qs;
 
   PREPARE (pg,
-           "lookup_aml_history",
+           "lookup_aml_history_desc",
            "SELECT"
            " lo.decision_time"
+           ",lo.outcome_serial_id"
            ",ah.justification"
            ",ah.decider_pub"
            ",lo.jproperties::TEXT"
@@ -154,10 +164,32 @@ TEH_PG_lookup_aml_history (
            " JOIN legitimization_outcomes lo"
            "   USING (outcome_serial_id)"
            " WHERE ah.h_payto=$1"
-           " ORDER BY decision_time DESC, outcome_serial_id DESC;");
+           "   AND lo.outcome_serial_id < $2"
+           " ORDER BY outcome_serial_id DESC"
+           " LIMIT $3;");
+  PREPARE (pg,
+           "lookup_aml_history_asc",
+           "SELECT"
+           " lo.decision_time"
+           ",lo.outcome_serial_id"
+           ",ah.justification"
+           ",ah.decider_pub"
+           ",lo.jproperties::TEXT"
+           ",lo.jnew_rules::TEXT"
+           ",lo.to_investigate"
+           ",lo.is_active"
+           " FROM aml_history ah"
+           " JOIN legitimization_outcomes lo"
+           "   USING (outcome_serial_id)"
+           " WHERE ah.h_payto=$1"
+           "   AND lo.outcome_serial_id > $2"
+           " ORDER BY outcome_serial_id ASC"
+           " LIMIT $3;");
   qs = GNUNET_PQ_eval_prepared_multi_select (
     pg->conn,
-    "lookup_aml_history",
+    (limit < 0)
+    ? "lookup_aml_history_desc"
+    : "lookup_aml_history_asc",
     params,
     &handle_aml_entry,
     &ahc);
