@@ -21,9 +21,9 @@
 #ifndef PG_LOOKUP_DENOMINATION_KEY_H
 #define PG_LOOKUP_DENOMINATION_KEY_H
 
-#include "taler_util.h"
-#include "taler_json_lib.h"
-#include "taler_exchangedb_plugin.h"
+#include "taler/taler_util.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_exchangedb_plugin.h"
 /**
  * Lookup information about current denomination key.
  *
