@@ -21,9 +21,9 @@
 #ifndef PG_PERSIST_POLICY_DETAILS_H
 #define PG_PERSIST_POLICY_DETAILS_H
 
-#include "taler_util.h"
-#include "taler_json_lib.h"
-#include "taler_exchangedb_plugin.h"
+#include "taler/taler_util.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_exchangedb_plugin.h"
 
 
 /* Persist the details to a policy in the policy_details table.  If there
