@@ -195,10 +195,10 @@ TEH_PG_select_aml_decisions (
            ",ah.justification"
            ",lo.decision_time"
            ",lo.expiration_time"
-           ",lo.jproperties"
+           ",lo.jproperties::TEXT"
            ",lo.to_investigate"
            ",lo.is_active"
-           ",lo.jnew_rules"
+           ",lo.jnew_rules::TEXT"
            ",kt.is_wallet"
            ",wt.payto_uri"
            " FROM legitimization_outcomes lo"
@@ -222,10 +222,10 @@ TEH_PG_select_aml_decisions (
            ",ah.justification"
            ",lo.decision_time"
            ",lo.expiration_time"
-           ",lo.jproperties"
+           ",lo.jproperties::TEXT"
            ",lo.to_investigate"
            ",lo.is_active"
-           ",lo.jnew_rules"
+           ",lo.jnew_rules::TEXT"
            ",kt.is_wallet"
            ",wt.payto_uri"
            " FROM legitimization_outcomes lo"
