@@ -1,6 +1,6 @@
 /*
    This file is part of TALER
-   Copyright (C) 2022 Taler Systems SA
+   Copyright (C) 2022, 2025 Taler Systems SA
 
    TALER is free software; you can redistribute it and/or modify it under the
    terms of the GNU General Public License as published by the Free Software
@@ -18,10 +18,10 @@
  * @brief Implementation of the select_refreshes_above_serial_id function for Postgres
  * @author Christian Grothoff
  */
-#include "platform.h"
-#include "taler_error_codes.h"
-#include "taler_dbevents.h"
-#include "taler_pq_lib.h"
+#include "taler/platform.h"
+#include "taler/taler_error_codes.h"
+#include "taler/taler_dbevents.h"
+#include "taler/taler_pq_lib.h"
 #include "pg_select_refreshes_above_serial_id.h"
 #include "pg_helper.h"
 
@@ -72,34 +72,37 @@ refreshs_serial_helper_cb (void *cls,
 
   for (unsigned int i = 0; i<num_results; i++)
   {
-    struct TALER_DenominationPublicKey denom_pub;
+    struct TALER_DenominationPublicKey old_denom_pub;
     struct TALER_CoinSpendPublicKeyP coin_pub;
     struct TALER_CoinSpendSignatureP coin_sig;
-    struct TALER_AgeCommitmentHash h_age_commitment;
+    struct TALER_AgeCommitmentHashP h_age_commitment;
     bool ac_isnull;
     struct TALER_Amount amount_with_fee;
-    uint32_t noreveal_index;
     uint64_t rowid;
     struct TALER_RefreshCommitmentP rc;
+    size_t num_nds;
+    uint64_t *nds;
     struct GNUNET_PQ_ResultSpec rs[] = {
-      TALER_PQ_result_spec_denom_pub ("denom_pub",
-                                      &denom_pub),
+      TALER_PQ_result_spec_denom_pub ("old_denom_pub",
+                                      &old_denom_pub),
+      GNUNET_PQ_result_spec_auto_from_type ("old_coin_pub",
+                                            &coin_pub),
       GNUNET_PQ_result_spec_allow_null (
         GNUNET_PQ_result_spec_auto_from_type ("age_commitment_hash",
                                               &h_age_commitment),
         &ac_isnull),
-      GNUNET_PQ_result_spec_auto_from_type ("old_coin_pub",
-                                            &coin_pub),
       GNUNET_PQ_result_spec_auto_from_type ("old_coin_sig",
                                             &coin_sig),
       TALER_PQ_RESULT_SPEC_AMOUNT ("amount_with_fee",
                                    &amount_with_fee),
-      GNUNET_PQ_result_spec_uint32 ("noreveal_index",
-                                    &noreveal_index),
-      GNUNET_PQ_result_spec_uint64 ("melt_serial_id",
+      GNUNET_PQ_result_spec_uint64 ("refresh_id",
                                     &rowid),
       GNUNET_PQ_result_spec_auto_from_type ("rc",
                                             &rc),
+      GNUNET_PQ_result_spec_array_uint64 (pg->conn,
+                                          "new_denominations_serials",
+                                          &num_nds,
+                                          &nds),
       GNUNET_PQ_result_spec_end
     };
     enum GNUNET_GenericReturnValue ret;
@@ -116,12 +119,13 @@ refreshs_serial_helper_cb (void *cls,
 
     ret = rsc->cb (rsc->cb_cls,
                    rowid,
-                   &denom_pub,
-                   ac_isnull ? NULL : &h_age_commitment,
+                   &old_denom_pub,
                    &coin_pub,
                    &coin_sig,
+                   ac_isnull ? NULL : &h_age_commitment,
                    &amount_with_fee,
-                   noreveal_index,
+                   num_nds,
+                   nds,
                    &rc);
     GNUNET_PQ_cleanup_result (rs);
     if (GNUNET_OK != ret)
@@ -151,28 +155,29 @@ TEH_PG_select_refreshes_above_serial_id (
   enum GNUNET_DB_QueryStatus qs;
 
   PREPARE (pg,
-           "audit_get_refresh_commitments_incr",
+           "select_refreshes_above_serial_id",
            "SELECT"
-           " denom.denom_pub"
-           ",kc.coin_pub AS old_coin_pub"
+           " denom.denom_pub AS old_denom_pub"
+           ",r.old_coin_pub"
            ",kc.age_commitment_hash"
-           ",old_coin_sig"
-           ",amount_with_fee"
-           ",noreveal_index"
-           ",melt_serial_id"
-           ",rc"
-           " FROM refresh_commitments"
-           "   JOIN known_coins kc"
-           "     ON (refresh_commitments.old_coin_pub = kc.coin_pub)"
-           "   JOIN denominations denom"
-           "     ON (kc.denominations_serial = denom.denominations_serial)"
-           " WHERE melt_serial_id>=$1"
-           " ORDER BY melt_serial_id ASC;");
-  qs = GNUNET_PQ_eval_prepared_multi_select (pg->conn,
-                                             "audit_get_refresh_commitments_incr",
-                                             params,
-                                             &refreshs_serial_helper_cb,
-                                             &rsc);
+           ",r.old_coin_sig"
+           ",r.amount_with_fee"
+           ",r.refresh_id"
+           ",r.rc"
+           ",r.denom_serials AS new_denominations_serials"
+           " FROM refresh r"
+           " JOIN known_coins kc"
+           "   ON (r.old_coin_pub = kc.coin_pub)"
+           " JOIN denominations denom"
+           "   ON (kc.denominations_serial = denom.denominations_serial)"
+           " WHERE refresh_id>=$1"
+           " ORDER BY refresh_id ASC;");
+  qs = GNUNET_PQ_eval_prepared_multi_select (
+    pg->conn,
+    "select_refreshes_above_serial_id",
+    params,
+    &refreshs_serial_helper_cb,
+    &rsc);
   if (GNUNET_OK != rsc.status)
     return GNUNET_DB_STATUS_HARD_ERROR;
   return qs;
