@@ -18,10 +18,10 @@
  * @brief Low-level (statement-level) Postgres database access for the exchange
  * @author Christian Grothoff
  */
-#include "platform.h"
-#include "taler_error_codes.h"
-#include "taler_dbevents.h"
-#include "taler_pq_lib.h"
+#include "taler/platform.h"
+#include "taler/taler_error_codes.h"
+#include "taler/taler_dbevents.h"
+#include "taler/taler_pq_lib.h"
 #include "pg_select_reserve_close_info.h"
 #include "pg_helper.h"
 
@@ -57,7 +57,7 @@ TEH_PG_select_reserve_close_info (
            "   USING (reserve_pub)"
            " LEFT JOIN wire_targets wt"
            "   ON (ri.wire_source_h_payto = wt.wire_target_h_payto)"
-           " WHERE reserve_pub=$1;");
+           " WHERE r.reserve_pub=$1;");
   return GNUNET_PQ_eval_prepared_singleton_select (
     pg->conn,
     "select_reserve_close_info",
