@@ -18,10 +18,10 @@
  * @brief Implementation of the select_reserves_in_above_serial_id function for Postgres
  * @author Christian Grothoff
  */
-#include "platform.h"
-#include "taler_error_codes.h"
-#include "taler_dbevents.h"
-#include "taler_pq_lib.h"
+#include "taler/platform.h"
+#include "taler/taler_error_codes.h"
+#include "taler/taler_dbevents.h"
+#include "taler/taler_pq_lib.h"
 #include "pg_select_reserves_in_above_serial_id.h"
 #include "pg_helper.h"
 
@@ -138,26 +138,27 @@ TEH_PG_select_reserves_in_above_serial_id (
   enum GNUNET_DB_QueryStatus qs;
 
   PREPARE (pg,
-           "audit_reserves_in_get_transactions_incr",
+           "select_reserves_in_above_serial_id",
            "SELECT"
            " reserves.reserve_pub"
            ",wire_reference"
            ",credit"
            ",execution_date"
-           ",payto_uri AS sender_account_details"
+           ",wt.payto_uri AS sender_account_details"
            ",reserve_in_serial_id"
            " FROM reserves_in"
            " JOIN reserves"
            "   USING (reserve_pub)"
-           " JOIN wire_targets"
+           " JOIN wire_targets wt"
            "   ON (wire_source_h_payto = wire_target_h_payto)"
            " WHERE reserve_in_serial_id>=$1"
            " ORDER BY reserve_in_serial_id;");
-  qs = GNUNET_PQ_eval_prepared_multi_select (pg->conn,
-                                             "audit_reserves_in_get_transactions_incr",
-                                             params,
-                                             &reserves_in_serial_helper_cb,
-                                             &risc);
+  qs = GNUNET_PQ_eval_prepared_multi_select (
+    pg->conn,
+    "select_reserves_in_above_serial_id",
+    params,
+    &reserves_in_serial_helper_cb,
+    &risc);
   if (GNUNET_DB_STATUS_SOFT_ERROR == qs)
     return qs;
   if (GNUNET_OK != risc.status)
