@@ -21,9 +21,9 @@
 #ifndef PG_START_READ_ONLY_H
 #define PG_START_READ_ONLY_H
 
-#include "taler_util.h"
-#include "taler_json_lib.h"
-#include "taler_exchangedb_plugin.h"
+#include "taler/taler_util.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_exchangedb_plugin.h"
 
 /**
  * Start a READ ONLY serializable transaction.
