@@ -21,9 +21,9 @@
 #ifndef PG_STORE_WIRE_TRANSFER_OUT_H
 #define PG_STORE_WIRE_TRANSFER_OUT_H
 
-#include "taler_util.h"
-#include "taler_json_lib.h"
-#include "taler_exchangedb_plugin.h"
+#include "taler/taler_util.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_exchangedb_plugin.h"
 /**
  * Store information about an outgoing wire transfer that was executed.
  *
