@@ -69,8 +69,8 @@ TEH_PG_update_wire (
            " SET"
            "  is_active=$2"
            " ,conversion_url=$3"
-           " ,debit_restrictions=$4"
-           " ,credit_restrictions=$5"
+           " ,debit_restrictions=$4::TEXT::JSONB"
+           " ,credit_restrictions=$5::TEXT::JSONB"
            " ,last_change=$6"
            " ,master_sig=$7"
            " ,bank_label=$8"
