@@ -136,6 +136,7 @@
 #include "pg_kyc_provider_account_lookup.h"
 #include "pg_kycauth_in_insert.h"
 #include "pg_lookup_active_legitimization.h"
+#include "pg_lookup_aml_file_number.h"
 #include "pg_lookup_aml_history.h"
 #include "pg_lookup_aml_officer.h"
 #include "pg_lookup_auditor_status.h"
@@ -629,6 +630,8 @@ libtaler_plugin_exchangedb_postgres_init (void *cls)
     = &TEH_PG_gc;
   plugin->select_coin_deposits_above_serial_id
     = &TEH_PG_select_coin_deposits_above_serial_id;
+  plugin->lookup_aml_file_number
+    = &TEH_PG_lookup_aml_file_number;
   plugin->lookup_aml_history
     = &TEH_PG_lookup_aml_history;
   plugin->lookup_kyc_history
