@@ -1113,7 +1113,9 @@ TALER_MHD_reply_cors_preflight (struct MHD_Connection *connection);
 
 
 /**
- * Load SPA files from @a dir
+ * Load SPA files from @a dir, relative to the project's
+ * data directory.
+ *
  *
  * @param pd project data to use to determine the parent directory
  * @param dir directory suffix to append to our data directory with the location of the files of the SPA
@@ -1123,6 +1125,17 @@ struct TALER_MHD_Spa *
 TALER_MHD_spa_load (const struct GNUNET_OS_ProjectData *pd,
                     const char *dir);
 
+/**
+ * Load SPA files from absolute path to directory @a dn.
+ *
+ *
+ * @param dn directory with the location of the files of the SPA,
+ *        should be an absolute path.
+ * @return handle to serve static files from @a dir
+ */
+struct TALER_MHD_Spa *
+TALER_MHD_spa_load_dir (const char *dn);
+
 
 /**
  * Release resources used by SPA handler.
@@ -1148,4 +1161,111 @@ TALER_MHD_spa_handler (const struct TALER_MHD_Spa *spa,
                        const char *path);
 
 
+/**
+ * Information about a document #TALER_MHD_typst() should output.
+ */
+struct TALER_MHD_TypstDocument
+{
+  /**
+   * Form name, used to determine the Typst template to use.
+   * NULL if @e data is a JSON string with a PDF to inline.
+   */
+  const char *form_name;
+
+  /**
+   * Form data.
+   */
+  const json_t *data;
+};
+
+
+/**
+ * Context for generating PDF responses.
+ */
+struct TALER_MHD_TypstContext;
+
+
+/**
+ * Result from a #TALER_MHD_typst() operation.
+ */
+struct TALER_MHD_TypstResponse
+{
+
+  /**
+   * Error status of the operation.
+   */
+  enum TALER_ErrorCode ec;
+
+  /**
+   * Details depending on @e ec.
+   */
+  union
+  {
+    /**
+     * Hint if @e ec is not #TALER_EC_NONE.
+     */
+    const char *hint;
+
+    /**
+     * Filename with the result if @e ec is #TALER_EC_NONE.
+     */
+    const char *filename;
+  } details;
+
+};
+
+/**
+ * Function called with the result of a #TALER_MHD_typst() operation.
+ *
+ * @param cls closure
+ * @param tr result of the operation
+ */
+typedef void
+(*TALER_MHD_TypstResultCallback) (void *cls,
+                                  const struct TALER_MHD_TypstResponse *tr);
+
+
+/**
+ * Generate PDFs using Typst and combine them using pdftk.  The
+ * file will be returned to @a cb and after @a cb returns all data
+ * will be deleted from the local disk.
+ *
+ * @param cfg configuration to use (where to find Typst templates)
+ * @param remove_on_exit should the directory be removed when done?
+ * @param cfg_section_name name of the configuration section to use
+ * @param num_documents length of the @a docs array
+ * @param docs list of documents to combine into one large PDF
+ * @param cb function to call with the resulting file(name)
+ * @param cb_cls closure for @a cb
+ * @return NULL on error
+ */
+struct TALER_MHD_TypstContext *
+TALER_MHD_typst (
+  const struct GNUNET_CONFIGURATION_Handle *cfg,
+  bool remove_on_exit,
+  const char *cfg_section_name,
+  unsigned int num_documents,
+  const struct TALER_MHD_TypstDocument docs[static num_documents],
+  TALER_MHD_TypstResultCallback cb,
+  void *cb_cls);
+
+
+/**
+ * Abort all typst response generation processes.
+ * To be used when the system is shutting down.
+ */
+void
+TALER_MHD_typst_cancel (struct TALER_MHD_TypstContext *tc);
+
+
+/**
+ * Create HTTP response from the PDF file at @a filename
+ *
+ * @param filename file to return as PDF
+ * @return NULL on error
+ */
+struct MHD_Response *
+TALER_MHD_response_from_pdf_file (const char *filename);
+
+
 #endif
