@@ -18,9 +18,9 @@
  * @brief helper routines to run some external JSON-to-JSON converter
  * @author Christian Grothoff
  */
-#include "platform.h"
-#include "taler_util.h"
-#include "taler_json_lib.h"
+#include "taler/platform.h"
+#include "taler/taler_util.h"
+#include "taler/taler_json_lib.h"
 #include <gnunet/gnunet_util_lib.h>
 
 
@@ -282,6 +282,10 @@ child_done_cb (void *cls,
                   "Failed to parse JSON from helper at %d: %s\n",
                   err.position,
                   err.text);
+      fprintf (stderr,
+               "%.*s\n",
+               (int) ec->read_pos,
+               (const char *) ec->read_buf);
     }
   }
   ec->cb (ec->cb_cls,
