@@ -903,6 +903,36 @@ webhook_conversion_cb (void *cls,
     kycaid_webhook_cancel (wh);
     return;
   }
+  if (! json_is_string (json_object_get (result,
+                                         "FORM_ID")))
+  {
+    /* Failure in our helper */
+    GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
+                "Mandatory FORM_ID not set in result\n");
+    json_dumpf (result,
+                stderr,
+                JSON_INDENT (2));
+    resp = TALER_MHD_MAKE_JSON_PACK (
+      GNUNET_JSON_pack_uint64 ("kycaid_http_status",
+                               wh->kycaid_response_code),
+      GNUNET_JSON_pack_object_incref ("kycaid_body",
+                                      (json_t *) wh->json_response));
+    wh->cb (wh->cb_cls,
+            wh->process_row,
+            &wh->h_payto,
+            wh->is_wallet,
+            wh->pd->section,
+            wh->applicant_id,
+            wh->verification_id,
+            TALER_KYCLOGIC_STATUS_PROVIDER_FAILED,
+            GNUNET_TIME_UNIT_ZERO_ABS, /* expiration */
+            NULL,
+            MHD_HTTP_BAD_GATEWAY,
+            resp);
+    kycaid_webhook_cancel (wh);
+    return;
+  }
+
   expiration = GNUNET_TIME_relative_to_absolute (wh->pd->validity);
   resp = MHD_create_response_from_buffer_static (0,
                                                  "");
