@@ -50,7 +50,7 @@ echo "$J" \
           --arg street "${STREET}" \
           --arg city "${CITY}" \
           --rawfile photo "${PHOTO_FILE}" \
-          '{FULL_NAME: $full_name, $street, $city, DATE_OF_BIRTH: .birthdate, "residences":.cc, "identification_number": ."identification-number", $photo}' \
+          '{"FORM_ID":"persona-individual",FULL_NAME: $full_name, $street, $city, DATE_OF_BIRTH: .birthdate, "residences":.cc, "identification_number": ."identification-number", $photo}' \
     | jq \
           'del(..|select(.==null))'
 
