@@ -19,15 +19,15 @@
  * @brief functions to add an AML decision by an AML officer
  * @author Christian Grothoff
  */
-#include "platform.h"
-#include "taler_json_lib.h"
+#include "taler/platform.h"
+#include "taler/taler_json_lib.h"
 #include <microhttpd.h>
 #include <gnunet/gnunet_curl_lib.h>
-#include "taler_exchange_service.h"
+#include "taler/taler_exchange_service.h"
 #include "exchange_api_curl_defaults.h"
-#include "taler_signatures.h"
-#include "taler_curl_lib.h"
-#include "taler_json_lib.h"
+#include "taler/taler_signatures.h"
+#include "taler/taler_curl_lib.h"
+#include "taler/taler_json_lib.h"
 
 
 struct TALER_EXCHANGE_AddAmlDecision
@@ -214,8 +214,9 @@ TALER_EXCHANGE_post_aml_decision (
     measure = GNUNET_JSON_PACK (
       GNUNET_JSON_pack_string ("check_name",
                                mi->check_name),
-      GNUNET_JSON_pack_string ("prog_name",
-                               mi->prog_name),
+      GNUNET_JSON_pack_allow_null (
+        GNUNET_JSON_pack_string ("prog_name",
+                                 mi->prog_name)),
       GNUNET_JSON_pack_allow_null (
         GNUNET_JSON_pack_object_incref ("context",
                                         (json_t *) mi->context))
