@@ -19,12 +19,12 @@
  * @brief common functions for the exchange API
  * @author Christian Grothoff
  */
-#include "platform.h"
-#include "taler_json_lib.h"
+#include "taler/platform.h"
+#include "taler/taler_json_lib.h"
 #include <gnunet/gnunet_curl_lib.h>
 #include "exchange_api_common.h"
 #include "exchange_api_handle.h"
-#include "taler_signatures.h"
+#include "taler/taler_signatures.h"
 
 
 const struct TALER_EXCHANGE_SigningPublicKey *
@@ -175,7 +175,7 @@ TALER_EXCHANGE_check_purse_coin_conflict_ (
   const char *exchange_url,
   const json_t *proof,
   struct TALER_DenominationHashP *h_denom_pub,
-  struct TALER_AgeCommitmentHash *phac,
+  struct TALER_AgeCommitmentHashP *phac,
   struct TALER_CoinSpendPublicKeyP *coin_pub,
   struct TALER_CoinSpendSignatureP *coin_sig)
 {
