@@ -19,16 +19,16 @@
  * @brief functions to obtain future online keys of the exchange
  * @author Christian Grothoff
  */
-#include "platform.h"
-#include "taler_json_lib.h"
+#include "taler/platform.h"
+#include "taler/taler_json_lib.h"
 #include <gnunet/gnunet_curl_lib.h>
 #include <microhttpd.h>
-#include "taler_exchange_service.h"
+#include "taler/taler_exchange_service.h"
 #include "exchange_api_curl_defaults.h"
-#include "taler_signatures.h"
-#include "taler_curl_lib.h"
-#include "taler_util.h"
-#include "taler_json_lib.h"
+#include "taler/taler_signatures.h"
+#include "taler/taler_curl_lib.h"
+#include "taler/taler_util.h"
+#include "taler/taler_json_lib.h"
 
 /**
  * Set to 1 for extra debug logging.
