@@ -19,14 +19,15 @@
  * @brief functions to disable an exchange wire method / bank account
  * @author Christian Grothoff
  */
-#include "platform.h"
-#include "taler_json_lib.h"
+#include "taler/platform.h"
+#include "taler/taler_json_lib.h"
 #include <gnunet/gnunet_curl_lib.h>
-#include "taler_exchange_service.h"
+#include <microhttpd.h>
+#include "taler/taler_exchange_service.h"
 #include "exchange_api_curl_defaults.h"
-#include "taler_signatures.h"
-#include "taler_curl_lib.h"
-#include "taler_json_lib.h"
+#include "taler/taler_signatures.h"
+#include "taler/taler_curl_lib.h"
+#include "taler/taler_json_lib.h"
 
 
 struct TALER_EXCHANGE_ManagementWireDisableHandle
