@@ -20,17 +20,17 @@
  *        an initial set of deposits (and a contract)
  * @author Christian Grothoff
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include <jansson.h>
 #include <microhttpd.h> /* just for HTTP status codes */
 #include <gnunet/gnunet_util_lib.h>
 #include <gnunet/gnunet_json_lib.h>
 #include <gnunet/gnunet_curl_lib.h>
-#include "taler_json_lib.h"
-#include "taler_exchange_service.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_exchange_service.h"
 #include "exchange_api_handle.h"
 #include "exchange_api_common.h"
-#include "taler_signatures.h"
+#include "taler/taler_signatures.h"
 #include "exchange_api_curl_defaults.h"
 
 
@@ -57,7 +57,7 @@ struct Deposit
   /**
    * Age restriction hash for the coin.
    */
-  struct TALER_AgeCommitmentHash ahac;
+  struct TALER_AgeCommitmentHashP ahac;
 
   /**
    * How much did we say the coin contributed.
@@ -288,7 +288,7 @@ handle_purse_create_deposit_finished (void *cls,
           struct TALER_CoinSpendPublicKeyP coin_pub;
           struct TALER_CoinSpendSignatureP coin_sig;
           struct TALER_DenominationHashP h_denom_pub;
-          struct TALER_AgeCommitmentHash phac;
+          struct TALER_AgeCommitmentHashP phac;
           bool found = false;
 
           if (GNUNET_OK !=
@@ -497,9 +497,9 @@ TALER_EXCHANGE_purse_create_with_deposit (
     const struct TALER_AgeCommitmentProof *acp = deposit->age_commitment_proof;
     struct Deposit *d = &pch->deposits[i];
     json_t *jdeposit;
-    struct TALER_AgeCommitmentHash *aghp = NULL;
-    struct TALER_AgeAttestation attest;
-    struct TALER_AgeAttestation *attestp = NULL;
+    struct TALER_AgeCommitmentHashP *aghp = NULL;
+    struct TALER_AgeAttestationP attest;
+    struct TALER_AgeAttestationP *attestp = NULL;
 
     if (NULL != acp)
     {
