@@ -20,17 +20,17 @@
  *        into an account
  * @author Christian Grothoff
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include <jansson.h>
 #include <microhttpd.h> /* just for HTTP status codes */
 #include <gnunet/gnunet_util_lib.h>
 #include <gnunet/gnunet_json_lib.h>
 #include <gnunet/gnunet_curl_lib.h>
-#include "taler_json_lib.h"
-#include "taler_exchange_service.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_exchange_service.h"
 #include "exchange_api_handle.h"
 #include "exchange_api_common.h"
-#include "taler_signatures.h"
+#include "taler/taler_signatures.h"
 #include "exchange_api_curl_defaults.h"
 
 
