@@ -19,16 +19,16 @@
  * @brief Implementation of the POST /reserves/$RESERVE_PUB/history requests
  * @author Christian Grothoff
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include <jansson.h>
 #include <microhttpd.h> /* just for HTTP history codes */
 #include <gnunet/gnunet_util_lib.h>
 #include <gnunet/gnunet_json_lib.h>
 #include <gnunet/gnunet_curl_lib.h>
-#include "taler_exchange_service.h"
-#include "taler_json_lib.h"
+#include "taler/taler_exchange_service.h"
+#include "taler/taler_json_lib.h"
 #include "exchange_api_handle.h"
-#include "taler_signatures.h"
+#include "taler/taler_signatures.h"
 #include "exchange_api_curl_defaults.h"
 
 
@@ -340,12 +340,14 @@ parse_withdraw (struct TALER_EXCHANGE_ReserveHistoryEntry *rh,
         GNUNET_JSON_parse_free (withdraw_spec);
         return GNUNET_SYSERR;
       }
-      TALER_amount_add (&fee_acc,
-                        &fee_acc,
-                        &dki->fees.withdraw);
-      TALER_amount_add (&amount_acc,
-                        &amount_acc,
-                        &dki->value);
+      GNUNET_assert (0 <=
+                     TALER_amount_add (&fee_acc,
+                                       &fee_acc,
+                                       &dki->fees.withdraw));
+      GNUNET_assert (0 <=
+                     TALER_amount_add (&amount_acc,
+                                       &amount_acc,
+                                       &dki->value));
     }
 
     if ( (GNUNET_YES !=
