@@ -20,10 +20,10 @@
  * @author Benedikt Mueller
  * @author Christian Grothoff
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include <zlib.h>
-#include "taler_util.h"
-#include "taler_mhd_lib.h"
+#include "taler/taler_util.h"
+#include "taler/taler_mhd_lib.h"
 
 
 /**
@@ -40,7 +40,8 @@ TALER_MHD_setup (enum TALER_MHD_GlobalOptions go)
 
 
 void
-TALER_MHD_add_global_headers (struct MHD_Response *response)
+TALER_MHD_add_global_headers (struct MHD_Response *response,
+                              bool allow_store)
 {
   if (0 != (TM_go & TALER_MHD_GO_FORCE_CONNECTION_CLOSE))
     GNUNET_break (MHD_YES ==
@@ -58,37 +59,61 @@ TALER_MHD_add_global_headers (struct MHD_Response *response)
                                          /* Not available as MHD constant yet */
                                          "Access-Control-Expose-Headers",
                                          "*"));
+  if (! allow_store)
+    GNUNET_break (MHD_YES ==
+                  MHD_add_response_header (response,
+                                           MHD_HTTP_HEADER_CACHE_CONTROL,
+                                           "no-store"));
 }
 
 
-MHD_RESULT
-TALER_MHD_can_compress (struct MHD_Connection *connection)
+enum TALER_MHD_CompressionType
+TALER_MHD_can_compress (struct MHD_Connection *connection,
+                        enum TALER_MHD_CompressionType max)
 {
+  struct NameMap
+  {
+    const char *name;
+    enum TALER_MHD_CompressionType ct;
+  } map[] = {
+    /* sorted largest to smallest on purpose! */
+    { "zstd", TALER_MHD_CT_ZSTD },
+    { "gzip", TALER_MHD_CT_GZIP },
+    { "deflate", TALER_MHD_CT_DEFLATE },
+    { NULL, TALER_MHD_CT_NONE }
+  };
   const char *ae;
   const char *de;
 
   if (0 != (TM_go & TALER_MHD_GO_DISABLE_COMPRESSION))
-    return MHD_NO;
+    return TALER_MHD_CT_NONE;
   ae = MHD_lookup_connection_value (connection,
                                     MHD_HEADER_KIND,
                                     MHD_HTTP_HEADER_ACCEPT_ENCODING);
   if (NULL == ae)
-    return MHD_NO;
+    return TALER_MHD_CT_NONE;
   if (0 == strcmp (ae,
                    "*"))
     return MHD_YES;
-  de = strstr (ae,
-               "deflate");
-  if (NULL == de)
-    return MHD_NO;
-  if ( ( (de == ae) ||
-         (de[-1] == ',') ||
-         (de[-1] == ' ') ) &&
-       ( (de[strlen ("deflate")] == '\0') ||
-         (de[strlen ("deflate")] == ',') ||
-         (de[strlen ("deflate")] == ';') ) )
-    return MHD_YES;
-  return MHD_NO;
+  for (unsigned int i=0; NULL != map[i].name; i++)
+  {
+    const char *name = map[i].name;
+
+    if (map[i].ct > max)
+      continue; /* not allowed by client */
+    de = strstr (ae,
+                 name);
+    if (NULL == de)
+      continue;
+    if ( ( (de == ae) ||
+           (de[-1] == ',') ||
+           (de[-1] == ' ') ) &&
+         ( (de[strlen (name)] == '\0') ||
+           (de[strlen (name)] == ',') ||
+           (de[strlen (name)] == ';') ) )
+      return map[i].ct;
+  }
+  return TALER_MHD_CT_NONE;
 }
 
 
@@ -144,7 +169,8 @@ TALER_MHD_make_json (const json_t *json)
     GNUNET_break (0);
     return NULL;
   }
-  TALER_MHD_add_global_headers (response);
+  TALER_MHD_add_global_headers (response,
+                                false);
   GNUNET_break (MHD_YES ==
                 MHD_add_response_header (response,
                                          MHD_HTTP_HEADER_CONTENT_TYPE,
@@ -191,8 +217,9 @@ TALER_MHD_reply_json (struct MHD_Connection *connection,
   json_len = strlen (json_str);
   /* try to compress the body */
   is_compressed = MHD_NO;
-  if (MHD_YES ==
-      TALER_MHD_can_compress (connection))
+  if (TALER_MHD_CT_DEFLATE ==
+      TALER_MHD_can_compress (connection,
+                              TALER_MHD_CT_DEFLATE))
     is_compressed = TALER_MHD_body_compress (&json_str,
                                              &json_len);
   response = MHD_create_response_from_buffer (json_len,
@@ -204,7 +231,8 @@ TALER_MHD_reply_json (struct MHD_Connection *connection,
     GNUNET_break (0);
     return MHD_NO;
   }
-  TALER_MHD_add_global_headers (response);
+  TALER_MHD_add_global_headers (response,
+                                false);
   GNUNET_break (MHD_YES ==
                 MHD_add_response_header (response,
                                          MHD_HTTP_HEADER_CONTENT_TYPE,
@@ -262,7 +290,8 @@ TALER_MHD_reply_cors_preflight (struct MHD_Connection *connection)
     return MHD_NO;
   /* This adds the Access-Control-Allow-Origin header.
    * All endpoints of the exchange allow CORS. */
-  TALER_MHD_add_global_headers (response);
+  TALER_MHD_add_global_headers (response,
+                                true);
   GNUNET_break (MHD_YES ==
                 MHD_add_response_header (response,
                                          /* Not available as MHD constant yet */
@@ -285,87 +314,6 @@ TALER_MHD_reply_cors_preflight (struct MHD_Connection *connection)
 }
 
 
-MHD_RESULT
-TALER_MHD_reply_json_pack (struct MHD_Connection *connection,
-                           unsigned int response_code,
-                           const char *fmt,
-                           ...)
-{
-  json_t *json;
-  json_error_t jerror;
-
-  {
-    va_list argp;
-
-    va_start (argp,
-              fmt);
-    json = json_vpack_ex (&jerror,
-                          0,
-                          fmt,
-                          argp);
-    va_end (argp);
-  }
-
-  if (NULL == json)
-  {
-    GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                "Failed to pack JSON with format `%s': %s\n",
-                fmt,
-                jerror.text);
-    GNUNET_break (0);
-    return MHD_NO;
-  }
-
-  {
-    MHD_RESULT ret;
-
-    ret = TALER_MHD_reply_json (connection,
-                                json,
-                                response_code);
-    json_decref (json);
-    return ret;
-  }
-}
-
-
-struct MHD_Response *
-TALER_MHD_make_json_pack (const char *fmt,
-                          ...)
-{
-  json_t *json;
-  json_error_t jerror;
-
-  {
-    va_list argp;
-
-    va_start (argp, fmt);
-    json = json_vpack_ex (&jerror,
-                          0,
-                          fmt,
-                          argp);
-    va_end (argp);
-  }
-
-  if (NULL == json)
-  {
-    GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                "Failed to pack JSON with format `%s': %s\n",
-                fmt,
-                jerror.text);
-    GNUNET_break (0);
-    return NULL;
-  }
-
-  {
-    struct MHD_Response *response;
-
-    response = TALER_MHD_make_json (json);
-    json_decref (json);
-    return response;
-  }
-}
-
-
 struct MHD_Response *
 TALER_MHD_make_error (enum TALER_ErrorCode ec,
                       const char *detail)
@@ -440,7 +388,8 @@ TALER_MHD_reply_agpl (struct MHD_Connection *connection,
     GNUNET_break (0);
     return MHD_NO;
   }
-  TALER_MHD_add_global_headers (response);
+  TALER_MHD_add_global_headers (response,
+                                true);
   GNUNET_break (MHD_YES ==
                 MHD_add_response_header (response,
                                          MHD_HTTP_HEADER_CONTENT_TYPE,
@@ -484,7 +433,8 @@ TALER_MHD_reply_static (struct MHD_Connection *connection,
     GNUNET_break (0);
     return MHD_NO;
   }
-  TALER_MHD_add_global_headers (response);
+  TALER_MHD_add_global_headers (response,
+                                true);
   if (NULL != mime_type)
     GNUNET_break (MHD_YES ==
                   MHD_add_response_header (response,
