@@ -320,6 +320,7 @@ struct TALER_MHD_Spa *
 TALER_MHD_spa_load (const struct GNUNET_OS_ProjectData *pd,
                     const char *dir)
 {
+  struct TALER_MHD_Spa *spa;
   char *dn;
   char *path;
 
@@ -335,7 +336,9 @@ TALER_MHD_spa_load (const struct GNUNET_OS_ProjectData *pd,
                    path,
                    dir);
   GNUNET_free (path);
-  return TALER_MHD_spa_load_dir (dn);
+  spa = TALER_MHD_spa_load_dir (dn);
+  GNUNET_free (dn);
+  return spa;
 }
 
 
