@@ -184,23 +184,24 @@ inline_pdf_stage (struct TypstStage *stage,
   char *fn;
   size_t n;
   void *b;
+  int fd;
 
   if (NULL == str)
   {
     GNUNET_break (0);
     return false;
   }
-  if (GNUNET_OK !=
-      GNUNET_STRINGS_string_to_data_alloc (str,
-                                           strlen (str),
-                                           &b,
-                                           &n))
+  b = NULL;
+  n = GNUNET_STRINGS_base64_decode (str,
+                                    strlen (str),
+                                    &b);
+  if (NULL == b)
   {
     GNUNET_break (0);
     return false;
   }
   GNUNET_asprintf (&fn,
-                   "%s/external-XXXXXX",
+                   "%s/external-",
                    tmpdir);
   stage->filename = GNUNET_DISK_mktemp (fn);
   if (NULL == stage->filename)
@@ -211,18 +212,43 @@ inline_pdf_stage (struct TypstStage *stage,
     return false;
   }
   GNUNET_free (fn);
-
-  if (n !=
-      GNUNET_DISK_fn_write (stage->filename,
-                            b,
-                            n,
-                            GNUNET_DISK_PERM_USER_READ
-                            | GNUNET_DISK_PERM_USER_WRITE))
+  fd = open (stage->filename,
+             O_WRONLY | O_TRUNC,
+             S_IRUSR | S_IWUSR);
+  if (-1 == fd)
   {
+    GNUNET_log_strerror_file (GNUNET_ERROR_TYPE_ERROR,
+                              "open",
+                              stage->filename);
     GNUNET_free (b);
     GNUNET_free (stage->filename);
     return false;
   }
+
+  {
+    size_t off = 0;
+
+    while (off < n)
+    {
+      ssize_t r;
+
+      r = write (fd,
+                 b + off,
+                 n - off);
+      if (-1 == r)
+      {
+        GNUNET_log_strerror_file (GNUNET_ERROR_TYPE_ERROR,
+                                  "write",
+                                  stage->filename);
+        GNUNET_break (0 == close (fd));
+        GNUNET_free (b);
+        GNUNET_free (stage->filename);
+        return false;
+      }
+      off += r;
+    }
+  }
+  GNUNET_break (0 == close (fd));
   return true;
 }
 
@@ -290,7 +316,7 @@ pdftk_done_cb (void *cls,
                   "pdftk exited with status %d\n",
                   (int) exit_code);
       typst_context_fail (tc,
-                          42,
+                          TALER_EC_EXCHANGE_GENERIC_PDFTK_FAILURE,
                           "pdftk failed");
     }
     else
@@ -311,7 +337,7 @@ pdftk_done_cb (void *cls,
                 "pdftk died with signal %d\n",
                 (int) exit_code);
     typst_context_fail (tc,
-                        42,
+                        TALER_EC_EXCHANGE_GENERIC_PDFTK_CRASH,
                         "pdftk killed by signal");
     break;
   }
@@ -360,6 +386,21 @@ complete_response (void *cls)
 }
 
 
+/**
+ * Cancel typst. Wrapper task to do so asynchronously.
+ *
+ * @param[in] cls a `struct TALER_MHD_TypstContext`
+ */
+static void
+cancel_async (void *cls)
+{
+  struct TALER_MHD_TypstContext *tc = cls;
+
+  tc->t = NULL;
+  TALER_MHD_typst_cancel (tc);
+}
+
+
 /**
  * Called when a typst helper exited.
  *
@@ -404,9 +445,11 @@ typst_done_cb (void *cls,
                        "Typst exited with status %d",
                        (int) exit_code);
       typst_context_fail (tc,
-                          42,
+                          TALER_EC_EXCHANGE_GENERIC_TYPST_TEMPLATE_FAILURE,
                           err);
-      TALER_MHD_typst_cancel (tc);
+      GNUNET_assert (NULL == tc->t);
+      tc->t = GNUNET_SCHEDULER_add_now (&cancel_async,
+                                        tc);
       return;
     }
     break;
@@ -422,9 +465,11 @@ typst_done_cb (void *cls,
                        "Typst died with signal %d",
                        (int) exit_code);
       typst_context_fail (tc,
-                          42,
+                          TALER_EC_EXCHANGE_GENERIC_TYPST_CRASH,
                           err);
-      TALER_MHD_typst_cancel (tc);
+      GNUNET_assert (NULL == tc->t);
+      tc->t = GNUNET_SCHEDULER_add_now (&cancel_async,
+                                        tc);
       return;
     }
     break;
@@ -464,11 +509,19 @@ setup_stage (struct TypstStage *stage,
 
   if (NULL == doc->form_name)
   {
+    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                "Stage %u: Dumping inlined PDF attachment\n",
+                i);
     return inline_pdf_stage (stage,
                              tmpdir,
                              doc->data);
   }
 
+  GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+              "Stage %u: Handling form %s\n",
+              i,
+              doc->form_name);
+
   /* Setup inputs */
   {
     char *dirname;
@@ -520,7 +573,7 @@ setup_stage (struct TypstStage *stage,
     char *template_fn;
 
     GNUNET_asprintf (&template_fn,
-                     "%s%s",
+                     "%s%s.typ",
                      template_path,
                      doc->form_name);
     if (GNUNET_YES !=
@@ -641,6 +694,8 @@ TALER_MHD_typst (
     once = GNUNET_OK;
     break;
   case GNUNET_SYSERR:
+    GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
+                "PDF generation initialization failed before, not even trying again\n");
     return NULL;
   }
   tc = GNUNET_new (struct TALER_MHD_TypstContext);
@@ -691,12 +746,15 @@ TALER_MHD_typst (
       {
         char err[128];
 
+        GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
+                    "Typst setup failed on stage %u\n",
+                    i);
         GNUNET_snprintf (err,
                          sizeof (err),
                          "Typst setup failed on stage %u",
                          i);
         typst_context_fail (tc,
-                            42,
+                            TALER_EC_EXCHANGE_GENERIC_TYPST_TEMPLATE_FAILURE,
                             err);
         TALER_MHD_typst_cancel (tc);
         return NULL;
