@@ -18,7 +18,7 @@
  * @brief common defines for the pq functions
  * @author Özgür Kesim
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include "pq_common.h"
 
 struct TALER_PQ_AmountP
