@@ -1163,13 +1163,13 @@ extract_array_generic (
   *((void **) dst) = NULL;
 
   #define FAIL_IF(cond) \
-          do { \
-            if ((cond)) \
-            { \
-              GNUNET_break (! (cond)); \
-              goto FAIL; \
-            } \
-          } while (0)
+  do { \
+    if ((cond)) \
+    { \
+      GNUNET_break (! (cond)); \
+      goto FAIL; \
+    } \
+  } while (0)
 
   col_num = PQfnumber (result, fname);
   FAIL_IF (0 > col_num);
@@ -1252,6 +1252,54 @@ extract_array_generic (
         }
         return GNUNET_OK;
       }
+    case TALER_PQ_array_of_amount_currency:
+      {
+        struct TALER_Amount *amounts;
+        if (NULL != dst_size)
+          *dst_size = sizeof(struct TALER_Amount) * (header.dim);
+
+        amounts = GNUNET_new_array (header.dim,
+                                    struct TALER_Amount);
+        *((void **) dst) = amounts;
+
+        for (uint32_t i = 0; i < header.dim; i++)
+        {
+          struct TALER_PQ_AmountCurrencyP ap;
+          struct TALER_Amount *amount = &amounts[i];
+          uint32_t val;
+          size_t sz;
+
+          GNUNET_memcpy (&val,
+                         in,
+                         sizeof(val));
+          sz =  ntohl (val);
+          in += sizeof(val);
+
+          FAIL_IF ( (sz >= sizeof(ap)) ||
+                    (sz <= sizeof(ap) - TALER_CURRENCY_LEN) );
+
+          memset (&ap,
+                  0,
+                  sizeof(ap));
+          GNUNET_memcpy (&ap,
+                         in,
+                         sz);
+          FAIL_IF (3 != ntohl (ap.cnt));
+
+          amount->value = GNUNET_ntohll (ap.v);
+          amount->fraction = ntohl (ap.f);
+          GNUNET_memcpy (amount->currency,
+                         ap.c,
+                         TALER_CURRENCY_LEN);
+
+          FAIL_IF ('\0' != amount->currency[TALER_CURRENCY_LEN - 1]);
+          FAIL_IF (amount->value >= TALER_AMOUNT_MAX_VALUE);
+          FAIL_IF (amount->fraction >= TALER_AMOUNT_FRAC_BASE);
+
+          in += sz;
+        }
+        return GNUNET_OK;
+      }
     case TALER_PQ_array_of_denom_hash:
       if (NULL != dst_size)
         *dst_size = sizeof(struct TALER_DenominationHashP) * (header.dim);
@@ -1586,6 +1634,37 @@ TALER_PQ_result_spec_array_amount (
 }
 
 
+struct GNUNET_PQ_ResultSpec
+TALER_PQ_result_spec_array_amount_with_currency (
+  struct GNUNET_PQ_Context *db,
+  const char *name,
+  size_t *num,
+  struct TALER_Amount **amounts)
+{
+  struct ArrayResultCls *info = GNUNET_new (struct ArrayResultCls);
+
+  info->num = num;
+  info->typ = TALER_PQ_array_of_amount_currency;
+  info->db = db;
+  GNUNET_assert (GNUNET_OK ==
+                 GNUNET_PQ_get_oid_by_name (db,
+                                            "taler_amount_currency",
+                                            &info->oid));
+
+  {
+    struct GNUNET_PQ_ResultSpec res = {
+      .conv = extract_array_generic,
+      .cleaner = &array_cleanup,
+      .dst = (void *) amounts,
+      .fname = name,
+      .cls = info,
+    };
+
+    return res;
+  }
+}
+
+
 struct GNUNET_PQ_ResultSpec
 TALER_PQ_result_spec_array_hash_code (
   struct GNUNET_PQ_Context *db,
