@@ -91,7 +91,7 @@ USE_VALGRIND=""
 WIRE_DOMAIN="x-taler-bank"
 CONF_ORIG="$HOME/.config/taler.conf"
 LOGLEVEL="DEBUG"
-DEFAULT_SLEEP="0.2"
+DEFAULT_SLEEP="0.5"
 
 # Parse command-line options
 while getopts ':abc:d:DeEfghkL:mMnr:stu:vwWzZ' OPTION; do
@@ -143,6 +143,7 @@ while getopts ':abc:d:DeEfghkL:mMnr:stu:vwWzZ' OPTION; do
             # shellcheck disable=SC2016
             echo '  -r $MEX      -- which exchange to use at the merchant (optional)'
             echo '  -s           -- start backup/sync'
+            echo '  -S $SLEEP    -- set default sleep time between retries'
             echo '  -t           -- start taler-exchange-transfer'
             # shellcheck disable=SC2016
             echo '  -u $SECTION  -- exchange account to use'
@@ -177,6 +178,9 @@ while getopts ':abc:d:DeEfghkL:mMnr:stu:vwWzZ' OPTION; do
         s)
             START_BACKUP="1"
             ;;
+        S)
+            DEFAULT_SLEEP="$OPTARG"
+            ;;
         t)
             START_TRANSFER="1"
             ;;
@@ -258,8 +262,8 @@ fi
 
 if [ "1" = "$START_NEXUS" ]
 then
-    echo -n "Testing for libeufin-cli"
-    libeufin-cli --help >/dev/null </dev/null || exit_skip " MISSING"
+    echo -n "Testing for libeufin-nexus"
+    libeufin-nexus --help >/dev/null </dev/null || exit_skip " MISSING"
     echo " FOUND"
 fi
 
@@ -299,8 +303,16 @@ register_bank_account() {
     then
         # shellcheck disable=SC2001
         ENAME=$(echo "$3" | sed -e "s/ /+/g")
-        # Note: this assumes that $3 has no spaces. Should probably escape in the future..
-        PAYTO="payto://iban/SANDBOXX/${MAYBE_IBAN}?receiver-name=$ENAME"
+        if [ "$WIRE_DOMAIN" = "x-taler-bank" ]
+        then
+            # hostname
+            OPERATOR="localhost"
+            MAYBE_IBAN="$1"
+        else
+            # BIC
+            OPERATOR="SANDBOXX"
+        fi
+        PAYTO="payto://${WIRE_DOMAIN}/${OPERATOR}/${MAYBE_IBAN}?receiver-name=$ENAME"
         BODY='{"username":"'"$1"'","password":"'"$2"'","is_taler_exchange":'"$IS_EXCHANGE"',"name":"'"$3"'","payto_uri":"'"$PAYTO"'"}'
     else
         BODY='{"username":"'"$1"'","password":"'"$2"'","is_taler_exchange":'"$IS_EXCHANGE"',"name":"'"$3"'"}'
@@ -425,7 +437,7 @@ then
     echo " OK"
 fi
 
-if [[ "1" = "$START_NEXUS" || "1" = "$START_FAKEBANK" ]]
+if [[ "1" = "$START_BANK" || "1" = "$START_FAKEBANK" ]]
 then
     echo -n "Waiting for the bank"
     # Wait for bank to be available (usually the slowest)
@@ -787,7 +799,7 @@ M_DONE=0
 S_DONE=0
 K_DONE=0
 A_DONE=0
-for n in $(seq 1 20)
+for n in $(seq 1 30)
 do
     sleep "$DEFAULT_SLEEP"
     OK="0"
@@ -896,6 +908,7 @@ then
     echo " OK"
 
     echo -n "Setting up exchange keys ..."
+    rm -f test_exchange_api_home/.local/share/taler-exchange/offline/secm_tofus.pub
     taler-exchange-offline -c "$CONF" \
       download \
       sign \
