@@ -21,17 +21,17 @@
  * @brief testcase to test the KYC processes
  * @author Christian Grothoff
  */
-#include "platform.h"
-#include "taler_util.h"
-#include "taler_attributes.h"
-#include "taler_signatures.h"
-#include "taler_exchange_service.h"
-#include "taler_json_lib.h"
+#include "taler/platform.h"
+#include "taler/taler_util.h"
+#include "taler/taler_attributes.h"
+#include "taler/taler_signatures.h"
+#include "taler/taler_exchange_service.h"
+#include "taler/taler_json_lib.h"
 #include <gnunet/gnunet_util_lib.h>
 #include <microhttpd.h>
-#include "taler_bank_service.h"
-#include "taler_fakebank_lib.h"
-#include "taler_testing_lib.h"
+#include "taler/taler_bank_service.h"
+#include "taler/taler_fakebank_lib.h"
+#include "taler/taler_testing_lib.h"
 
 
 /**
@@ -605,20 +605,12 @@ run (void *cls,
       NULL,
       "EUR:1000",
       MHD_HTTP_UNAVAILABLE_FOR_LEGAL_REASONS),
-#if FIXME_LATER_9027
-    /* FIXME: the above created a legitimization_measure, but NOT
-       an actual *decision*, hence no decisions show up here!
-       Design issue: we may want _some_ way to expose _measures_ to AML staff!
-       What we have: wire_targets JOIN legitimization_measures
-         USING (account_token) WHERE wire_targets.wire_target_h_payto=$ACCT
-       will show that a _measure_ was triggered for the account.
-    */
-    TALER_TESTING_cmd_check_aml_decisions (
+    TALER_TESTING_cmd_get_active_legitimization_measures (
       "check-decisions-wallet-pending",
       "create-aml-officer-1",
       "wallet-trigger-kyc-for-aml",
-      MHD_HTTP_OK),
-#endif
+      MHD_HTTP_OK,
+      "{\"measures\": [{\"check_name\": \"oauth-test-id\", \"prog_name\": \"oauth-output-check\", \"context\": {}}], \"is_and_combinator\": true, \"verboten\": false}"),
     /* Test that we are not allowed to take AML decisions as our
        AML staff account is on read-only */
     TALER_TESTING_cmd_take_aml_decision (
@@ -771,7 +763,7 @@ run (void *cls,
       "get-kyc-info-form",
       0,  /* requirement index */
       "application/json",
-      "{\"form_id\":\"test\",\"full_name\":\"Bob\",\"birthdate\":\"1990-00-00\"}",
+      "{\"FORM_ID\":\"test\",\"FULL_NAME\":\"Bob\",\"DATE_OF_BIRTH\":\"1990-00-00\"}",
       MHD_HTTP_NO_CONTENT),
     /* now this should be allowed */
     TALER_TESTING_cmd_wallet_kyc_get (
