@@ -548,7 +548,7 @@ batch_deposit_traits (void *cls,
   const struct Coin *coin = &ds->coins[index];
   /* Will point to coin cmd internals. */
   const struct TALER_CoinSpendPrivateKeyP *coin_spent_priv;
-  struct TALER_CoinSpendPublicKeyP coin_spent_pub;
+  const struct TALER_CoinSpendPublicKeyP *coin_spent_pub;
   const struct TALER_AgeCommitmentProof *age_commitment_proof;
 
   if (index >= ds->num_coins)
@@ -569,6 +569,10 @@ batch_deposit_traits (void *cls,
         TALER_TESTING_get_trait_coin_priv (coin->coin_cmd,
                                            coin->coin_idx,
                                            &coin_spent_priv)) ||
+       (GNUNET_OK !=
+        TALER_TESTING_get_trait_coin_pub (coin->coin_cmd,
+                                          coin->coin_idx,
+                                          &coin_spent_pub)) ||
        (GNUNET_OK !=
         TALER_TESTING_get_trait_age_commitment_proof (coin->coin_cmd,
                                                       coin->coin_idx,
@@ -579,9 +583,6 @@ batch_deposit_traits (void *cls,
     return GNUNET_NO;
   }
 
-  GNUNET_CRYPTO_eddsa_key_get_public (&coin_spent_priv->eddsa_priv,
-                                      &coin_spent_pub.eddsa_pub);
-
   {
     struct TALER_TESTING_Trait traits[] = {
       /* First two traits are only available if
@@ -602,7 +603,7 @@ batch_deposit_traits (void *cls,
       TALER_TESTING_make_trait_coin_history (index,
                                              &coin->che),
       TALER_TESTING_make_trait_coin_pub (index,
-                                         &coin_spent_pub),
+                                         coin_spent_pub),
       TALER_TESTING_make_trait_denom_pub (index,
                                           coin->denom_pub),
       TALER_TESTING_make_trait_coin_priv (index,
