@@ -638,7 +638,7 @@ deposit_traits (void *cls,
   const struct TALER_TESTING_Command *coin_cmd;
   /* Will point to coin cmd internals. */
   const struct TALER_CoinSpendPrivateKeyP *coin_spent_priv;
-  struct TALER_CoinSpendPublicKeyP coin_spent_pub;
+  const struct TALER_CoinSpendPublicKeyP *coin_spent_pub;
   const struct TALER_AgeCommitmentProof *age_commitment_proof=NULL;
   const struct TALER_AgeCommitmentHashP *h_age_commitment=NULL;
 
@@ -662,6 +662,10 @@ deposit_traits (void *cls,
         TALER_TESTING_get_trait_coin_priv (coin_cmd,
                                            ds->coin_index,
                                            &coin_spent_priv)) ||
+       (GNUNET_OK !=
+        TALER_TESTING_get_trait_coin_pub (coin_cmd,
+                                          ds->coin_index,
+                                          &coin_spent_pub)) ||
        (GNUNET_OK !=
         TALER_TESTING_get_trait_age_commitment_proof (coin_cmd,
                                                       ds->coin_index,
@@ -676,9 +680,6 @@ deposit_traits (void *cls,
     return GNUNET_NO;
   }
 
-  GNUNET_CRYPTO_eddsa_key_get_public (&coin_spent_priv->eddsa_priv,
-                                      &coin_spent_pub.eddsa_pub);
-
   {
     struct TALER_TESTING_Trait traits[] = {
       /* First two traits are only available if
@@ -693,7 +694,7 @@ deposit_traits (void *cls,
       TALER_TESTING_make_trait_coin_priv (0,
                                           coin_spent_priv),
       TALER_TESTING_make_trait_coin_pub (0,
-                                         &coin_spent_pub),
+                                         coin_spent_pub),
       TALER_TESTING_make_trait_denom_pub (0,
                                           ds->denom_pub),
       TALER_TESTING_make_trait_coin_sig (0,
