@@ -117,6 +117,11 @@ struct WithdrawState
    */
   struct TALER_CoinSpendPrivateKeyP coin_priv;
 
+  /**
+   * Public key of the coin.
+   */
+  struct TALER_CoinSpendPublicKeyP coin_pub;
+
   /**
    * Blinding key used during the operation.
    */
@@ -313,6 +318,8 @@ withdraw_cb (void *cls,
     TALER_denom_sig_copy (&ws->sig,
                           &wr->details.ok.coin_details[0].denom_sig);
     ws->coin_priv = wr->details.ok.coin_details[0].coin_priv;
+    GNUNET_CRYPTO_eddsa_key_get_public (&ws->coin_priv.eddsa_priv,
+                                        &ws->coin_pub.eddsa_pub);
     ws->bks = wr->details.ok.coin_details[0].blinding_key;
     TALER_denom_ewv_copy (&ws->exchange_vals,
                           &wr->details.ok.coin_details[0].blinding_values);
@@ -561,6 +568,8 @@ withdraw_traits (void *cls,
                                               &ws->reserve_history),
     TALER_TESTING_make_trait_coin_priv (0 /* only one coin */,
                                         &ws->coin_priv),
+    TALER_TESTING_make_trait_coin_pub (0 /* only one coin */,
+                                       &ws->coin_pub),
     TALER_TESTING_make_trait_withdraw_seed (&ws->seed),
     TALER_TESTING_make_trait_blinding_seed (&ws->blinding_seed),
     TALER_TESTING_make_trait_withdraw_commitment (&ws->planchets_h),
