@@ -407,7 +407,7 @@ struct TALER_AgeAttestationPPS
    * Purpose must be #TALER_SIGNATURE_WALLET_AGE_ATTESTATION.
    * (no GNUNET_PACKED here because the struct is already packed)
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
 
   /**
    * Age mask that defines the underlying age groups
