@@ -21,8 +21,8 @@
  * @author Benedikt Mueller
  * @author Christian Grothoff
  */
-#include "platform.h"
-#include "taler_util.h"
+#include "taler/platform.h"
+#include "taler/taler_util.h"
 
 
 /**
