@@ -18,9 +18,9 @@
  * @brief Common functions for the exchange security modules
  * @author Florian Dold <dold@taler.net>
  */
-#include "platform.h"
-#include "taler_util.h"
-#include "taler_signatures.h"
+#include "taler/platform.h"
+#include "taler/taler_util.h"
+#include "taler/taler_signatures.h"
 #include "crypto_helper_common.h"
 
 
