@@ -18,9 +18,9 @@
  * @brief utility functions for running out-of-process private key operations
  * @author Christian Grothoff
  */
-#include "platform.h"
-#include "taler_util.h"
-#include "taler_signatures.h"
+#include "taler/platform.h"
+#include "taler/taler_util.h"
+#include "taler/taler_signatures.h"
 #include "crypto_helper_common.h"
 #include "secmod_rsa.h"
 #include <poll.h>
@@ -162,8 +162,9 @@ TALER_CRYPTO_helper_rsa_connect (
   if (GNUNET_OK !=
       try_connect (dh))
   {
-    TALER_CRYPTO_helper_rsa_disconnect (dh);
-    return NULL;
+    GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
+                "Could not connect to %s. Will keep trying\n",
+                "taler-exchange-helper-secmod-rsa");
   }
   return dh;
 }
