@@ -35,7 +35,7 @@ struct TALER_KycQueryPS
    * Purpose must be #TALER_SIGNATURE_KYC_AUTH.
    * Used for an EdDSA signature with the `union TALER_AccountPublicKeyP`.
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
 
 };
 
