@@ -36,7 +36,7 @@ struct TALER_MasterAmlOfficerStatusPS
    * Purpose is #TALER_SIGNATURE_MASTER_AML_KEY.   Signed
    * by a `struct TALER_MasterPublicKeyP` using EdDSA.
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
 
   /**
    * Time of the change.
@@ -129,7 +129,7 @@ struct TALER_MasterAddAuditorPS
    * Purpose is #TALER_SIGNATURE_MASTER_ADD_AUDITOR.   Signed
    * by a `struct TALER_MasterPublicKeyP` using EdDSA.
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
 
   /**
    * Time of the change.
@@ -212,7 +212,7 @@ struct TALER_MasterDelAuditorPS
    * Purpose is #TALER_SIGNATURE_MASTER_DEL_AUDITOR.   Signed
    * by a `struct TALER_MasterPublicKeyP` using EdDSA.
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
 
   /**
    * Time of the change.
@@ -280,7 +280,7 @@ struct TALER_MasterDenominationKeyRevocationPS
   /**
    * Purpose is #TALER_SIGNATURE_MASTER_DENOMINATION_KEY_REVOKED.
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
 
   /**
    * Hash of the denomination key.
@@ -341,7 +341,7 @@ struct TALER_MasterSigningKeyRevocationPS
   /**
    * Purpose is #TALER_SIGNATURE_MASTER_SIGNING_KEY_REVOKED.
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
 
   /**
    * The exchange's public key.
@@ -406,7 +406,7 @@ struct TALER_ExchangeSigningKeyValidityPS
   /**
    * Purpose is #TALER_SIGNATURE_MASTER_SIGNING_KEY_VALIDITY.
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
 
   /**
    * When does this signing key begin to be valid?
@@ -507,7 +507,7 @@ struct TALER_DenominationKeyValidityPS
   /**
    * Purpose is #TALER_SIGNATURE_MASTER_DENOMINATION_KEY_VALIDITY.
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
 
   /**
    * The long-term offline master key of the exchange that was
@@ -666,7 +666,7 @@ struct TALER_MasterAddWirePS
    * Purpose is #TALER_SIGNATURE_MASTER_ADD_WIRE.   Signed
    * by a `struct TALER_MasterPublicKeyP` using EdDSA.
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
 
   /**
    * Time of the change.
@@ -778,7 +778,7 @@ struct TALER_MasterDelWirePS
    * Purpose is #TALER_SIGNATURE_MASTER_DEL_WIRE.   Signed
    * by a `struct TALER_MasterPublicKeyP` using EdDSA.
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
 
   /**
    * Time of the change.
@@ -852,7 +852,7 @@ struct TALER_MasterWireFeePS
   /**
    * Purpose is #TALER_SIGNATURE_MASTER_WIRE_FEES.
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
 
   /**
    * Hash over the wire method (yes, H("x-taler-bank") or H("iban")), in lower
@@ -950,7 +950,7 @@ struct TALER_MasterGlobalFeePS
   /**
    * Purpose is #TALER_SIGNATURE_MASTER_GLOBAL_FEES.
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
 
   /**
    * Start date when the fee goes into effect.
@@ -1066,7 +1066,7 @@ struct TALER_MasterExtensionManifestPS
    * Purpose is #TALER_SIGNATURE_MASTER_EXTENSION.   Signed
    * by a `struct TALER_MasterPublicKeyP` using EdDSA.
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
 
   /**
    * Hash of the JSON object that represents the manifests of extensions.
@@ -1126,7 +1126,7 @@ struct TALER_MasterWireDetailsPS
   /**
    * Purpose is #TALER_SIGNATURE_MASTER_WIRE_DETAILS.
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
 
   /**
    * Hash over the account holder's payto:// URL.
@@ -1226,7 +1226,7 @@ struct TALER_PartnerConfigurationPS
   /**
    * Purpose is #TALER_SIGNATURE_MASTER_PARNTER_DETAILS
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
   struct TALER_MasterPublicKeyP partner_pub;
   struct GNUNET_TIME_TimestampNBO start_date;
   struct GNUNET_TIME_TimestampNBO end_date;
@@ -1313,7 +1313,7 @@ struct TALER_DrainProfitPS
   /**
    * Purpose is #TALER_SIGNATURE_MASTER_DRAIN_PROFITS
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
   struct TALER_WireTransferIdentifierRawP wtid;
   struct GNUNET_TIME_TimestampNBO date;
   struct TALER_AmountNBO amount;
