@@ -22,9 +22,9 @@
  * @brief initialize libgnunet OS subsystem for Taler.
  * @author Christian Grothoff
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include <gnunet/gnunet_util_lib.h>
-#include "taler_util.h"
+#include "taler/taler_util.h"
 
 /**
  * Default project data used for installation path detection
