@@ -233,7 +233,7 @@ static enum GNUNET_GenericReturnValue
 handle_sign_request (struct TES_Client *client,
                      const struct TALER_CRYPTO_EddsaSignRequest *sr)
 {
-  const struct GNUNET_CRYPTO_EccSignaturePurpose *purpose = &sr->purpose;
+  const struct GNUNET_CRYPTO_SignaturePurpose *purpose = &sr->purpose;
   size_t purpose_size = ntohs (sr->header.size) - sizeof (*sr)
                         + sizeof (*purpose);
   struct Key *key;
