@@ -19,8 +19,8 @@
  * @brief Tests for Taler-specific crypto logic
  * @author Christian Grothoff <christian@grothoff.org>
  */
-#include "platform.h"
-#include "taler_util.h"
+#include "taler/platform.h"
+#include "taler/taler_util.h"
 
 
 /**
@@ -129,8 +129,8 @@ test_planchets_rsa (uint8_t age)
   struct TALER_BlindedDenominationSignature blind_sig;
   struct TALER_FreshCoin coin;
   struct TALER_CoinPubHashP c_hash;
-  struct TALER_AgeCommitmentHash *ach = NULL;
-  struct TALER_AgeCommitmentHash ah = {0};
+  struct TALER_AgeCommitmentHashP *ach = NULL;
+  struct TALER_AgeCommitmentHashP ah = {0};
 
   alg_values = TALER_denom_ewv_rsa_singleton ();
   if (0 < age)
@@ -228,8 +228,8 @@ test_planchets_cs (uint8_t age)
   struct TALER_BlindedDenominationSignature blind_sig;
   struct TALER_FreshCoin coin;
   struct TALER_ExchangeBlindingValues alg_values;
-  struct TALER_AgeCommitmentHash *ach = NULL;
-  struct TALER_AgeCommitmentHash ah = {0};
+  struct TALER_AgeCommitmentHashP *ach = NULL;
+  struct TALER_AgeCommitmentHashP ah = {0};
 
   if (0 < age)
   {
