@@ -18,8 +18,8 @@
  * @brief Tests for RSA crypto helper
  * @author Christian Grothoff
  */
-#include "platform.h"
-#include "taler_util.h"
+#include "taler/platform.h"
+#include "taler/taler_util.h"
 
 /**
  * Configuration has 1 minute duration and 5 minutes lookahead, but
@@ -270,7 +270,7 @@ test_signing (struct TALER_CRYPTO_RsaDenominationHelper *dh)
   struct TALER_PlanchetMasterSecretP ps;
   const struct TALER_ExchangeBlindingValues *alg_values
     = TALER_denom_ewv_rsa_singleton ();
-  struct TALER_AgeCommitmentHash ach;
+  struct TALER_AgeCommitmentHashP ach;
   struct TALER_CoinPubHashP c_hash;
   struct TALER_CoinSpendPrivateKeyP coin_priv;
   union GNUNET_CRYPTO_BlindingSecretP bks;
@@ -463,7 +463,7 @@ test_batch_signing (struct TALER_CRYPTO_RsaDenominationHelper *dh,
   bool success = false;
   struct TALER_PlanchetMasterSecretP ps[batch_size];
   const struct TALER_ExchangeBlindingValues *alg_values;
-  struct TALER_AgeCommitmentHash ach[batch_size];
+  struct TALER_AgeCommitmentHashP ach[batch_size];
   struct TALER_CoinPubHashP c_hash[batch_size];
   struct TALER_CoinSpendPrivateKeyP coin_priv[batch_size];
   union GNUNET_CRYPTO_BlindingSecretP bks[batch_size];
@@ -681,7 +681,7 @@ perf_signing (struct TALER_CRYPTO_RsaDenominationHelper *dh,
   struct GNUNET_TIME_Relative duration;
   struct TALER_PlanchetMasterSecretP ps;
   struct TALER_CoinSpendPrivateKeyP coin_priv;
-  struct TALER_AgeCommitmentHash ach;
+  struct TALER_AgeCommitmentHashP ach;
   union GNUNET_CRYPTO_BlindingSecretP bks;
   const struct TALER_ExchangeBlindingValues *alg_values
     = TALER_denom_ewv_rsa_singleton ();
