@@ -18,8 +18,8 @@
  * @brief token family utility functions
  * @author Christian Blättler
  */
-#include "platform.h"
-#include "taler_util.h"
+#include "taler/platform.h"
+#include "taler/taler_util.h"
 
 
 void
