@@ -21,9 +21,9 @@
  * @author Benedikt Mueller
  * @author Christian Grothoff
  */
-#include "platform.h"
-#include "taler_util.h"
-#include "taler_attributes.h"
+#include "taler/platform.h"
+#include "taler/taler_util.h"
+#include "taler/taler_attributes.h"
 #include <gnunet/gnunet_json_lib.h>
 #include <unistr.h>
 
